@@ -1,7 +1,9 @@
 (use-modules (srfi srfi-13))
 (use-modules (ice-9 regex))
 (use-modules (ice-9 optargs))
+(load "ans-7.scm")
 
+(define DenemoKeypressActivatedCommand #f);;;is true while a keyboard shortcut is invoking a script, unless the script has set it to #f
 
 ;;;;;;;;;; create documentation for a command - this version just prints out basic info
 ;;;;;;;;;;;;;DocumentCommand
@@ -119,8 +121,10 @@
 			   (begin
 			     (if (eval-string positioning_command)
 				 (begin
-				    (eval-string  command)
-				    (ApplyToSelection command "(d-NextSelectedObject)"))))))
+				   (d-PushPosition)
+				   (eval-string  command)
+				   (d-PopPosition)
+				   (ApplyToSelection command "(d-NextSelectedObject)"))))))
 (define (PrevDirectiveOfTag tag)
   (let loop ()
     (if (d-PrevStandaloneDirective)
@@ -152,7 +156,76 @@
 ;(define cue- "")
 
 
+;;;;;;;;;;;;;;;; Double-Stroke for sequencing keypresses. By Nils Gey June 2010
+;One parameter for the GUI-version or help window. This is the version that appears if someone clicks on the menu version.
+;Ten optional parameters given as strings which can be only MENU commands: complete scheme syntax with (d-), but as string "" and with escaped \" in them. They return #f if not defined
+;gui-version can be any command to aid the user. Most likely it will we a tooltip or better a GUI with radio buttons with all commands (if (not #f) ...) and help texts and maybe additional parameters.
+;Right now its hardwired to the number keys and space for help. The reason is because the keybindings for number keys can change. If there were modal or wrapper commands for numberkeys (which they were some time ago) this script could be done better with (d-GetCommand) instead of (d-GetKeypress). Its also possible to create an even more insane version with 20 optional parameters, 10 for the actions, 10 for the keys.
 
+(define* (doublestroke gui-version #:optional (first "#f") (second "#f") (third "#f") (fourth "#f") (fifth "#f") (sixth "#f") (seventh "#f") (eighth "#f") (ninth "#f") (tenth "#f"))
+
+;Create a keybinding for a non-"#f" command, trimming (d- ... ) first.  Used for the [Return] variant.
+(define (doublestroke::bind action numberasstring) 
+		(if (not (string=? action "#f" ))
+			(d-AddKeybinding  (substring action 3 (- (string-length action) 1) )  numberasstring)
+			(d-AddKeybinding (d-GetId "NoOp") numberasstring)))
+
+; Create a fallback-GUI which just lists all commands as radio-buttons. Used for the [space] variant.
+(define (doublestroke::fallbackgui)
+	(define doublestroke::result #f)
+	
+	(define (bo action) ; BuildOption
+		(if (not (string=? action "#f" ))
+			(string-append action stop)
+			""))
+
+	(if (not gui-version) ;just a small performance-tweak
+		(begin
+			(set! doublestroke::result (d-GetOption  (string-append (bo first)  (bo second)  (bo third)  (bo fourth)  (bo fifth)  (bo sixth)  (bo seventh)  (bo eighth)  (bo ninth)  (bo tenth)) ))
+			(if doublestroke::result (eval-string doublestroke::result)))))
+
+
+; Short command to invoke the gui which tests if the author specified his own first.
+(define (doublestroke::invokegui)
+	(if gui-version (eval-string gui-version)
+			 	 (doublestroke::fallbackgui)))
+
+; The real action. Wait for a keypress and decide what do with it afterwards, Space triggers the GUI, Return locks-in the commands and makes them permanent keybindings.
+(if DenemoKeypressActivatedCommand
+	(begin 
+	(case (string->symbol (d-GetKeypress))
+		((#{1}#)  (eval-string first))
+		((#{2}#)  (eval-string second))
+		((#{3}#)  (eval-string third))
+		((#{4}#)  (eval-string fourth))
+		((#{5}#)  (eval-string fifth))
+		((#{6}#)  (eval-string sixth))
+		((#{7}#)  (eval-string seventh))
+		((#{8}#)  (eval-string eighth))
+		((#{9}#)  (eval-string ninth))
+		((#{0}#)  (eval-string tenth))
+		((space)  (doublestroke::invokegui))
+		((Return) (begin
+				(doublestroke::bind first "1")
+				(doublestroke::bind second "2")
+				(doublestroke::bind third "3")
+				(doublestroke::bind fourth "4")
+				(doublestroke::bind fifth "5")
+				(doublestroke::bind sixth "6")
+				(doublestroke::bind seventh "7")
+				(doublestroke::bind eighth "8")
+				(doublestroke::bind ninth "9")								
+				(doublestroke::bind tenth "0")
+				))
+		(else #f))
+	  (set! DenemoKeypressActivatedCommand #f))
+	  
+	 (doublestroke::invokegui) )) ; if not DenemoKeypressActivated
+
+	; Example, where key 6 to 9 are not defined. The WarningDialog shows if you press [space] or invoke the command through the menu. 
+	; (doublestroke "(d-WarningDialog \"After invoking the command, what you already have done right now, press a number key to specify number to print to the console or any other key to abort.\n\")" 
+	; "(d-Finger1)"  "(d-Finger2)" "(d-Finger3)"  "(d-Finger4)"  "(d-Finger5)" "#f" "#f" "#f" "#f" "(d-Finger0)")
+	
 
 ;;;;;;;;;;;;;;;;; ExtraOffset
 ;;; the parameter "what" is the LilyPond grob that is being tweaked - it may not be the tag of the DenemoDirective that is being edited
@@ -761,6 +834,65 @@
 	(d-DirectivePut-standalone-postfix "Anacrusis" (string-append "\\partial 128*" (number->string duration) " " ))))))
 
 
+;;;;;;;;;;;;;;;;;
+(define (MeasureEmpty?) (equal? "None" (d-GetType)))
+
+;;;;;;;;;;;;;;;;;;
+(define* (GetPrevailingTimeSig #:optional (numberorstring #f) ) 
+	(if numberorstring
+		(string->number (d-InsertTimeSig "query=timesigname"))
+		(d-InsertTimeSig "query=timesigname")
+	))
+
+
+
+;;;;;;;Get Measure Filling Status
+(define (MeasureFillStatus)
+(let script ((MaxTicks 0) (return #f))
+(d-PushPosition)
+(GoToMeasureEnd)
+(set! MaxTicks (* 1536 (GetPrevailingTimeSig #t) )) ; How many ticks are in a 100% filled measure?
+
+(set! return (cond 
+ 	((not(d-GetEndTick)) #f) ; empty
+ 	((< (d-GetEndTick) MaxTicks) #f) ; underful
+ 	((= MaxTicks (d-GetEndTick)) 1)  ; 100% filled
+ 	((< MaxTicks (d-GetEndTick)) 2) ; >100% filled
+	(else  (display "strange!")) ; ?
+ 	))
+  (d-PopPosition)
+  return
+))
+
+(define (EmptyMeasure?)
+  (not (d-GetEndTick)))
+
+(define (UnderfullMeasure?)
+  (or (EmptyMeasure?)
+     (not (MeasureFillStatus))))
+
+(define (FullDurationMeasure?)
+  (and (not (UnderfullMeasure?))
+       (= 1 (MeasureFillStatus))))
+
+(define (OverfullMeasure?)
+  (= 2 (MeasureFillStatus)))
+  ;;(and (not (EmptyMeasure?)) 
+ ;; (> (d-GetEndTick) (* 1536 (GetPrevailingTimeSig #t)))))
+
+(define (MeasureComplete?) (or (FullDurationMeasure?) 
+			       (d-Directive-standalone? "Anacrusis")
+			       (d-Directive-standalone? "ShortMeasure")))
+
+(define (Paste::MeasureBreakInClipboard?)
+(let searchformeasurebreak ((counter 1))  ;start at the second position to avoid leading measurebreaks, which do not count. 
+		(case (d-GetClipObjType 0 counter) 
+		  ((#f) #f ) ; No object left
+		  ((8) #t) ; Measurebreak found
+		  (else (searchformeasurebreak (+ 1 counter)))
+   		)))
+   		
+   		
 ;;;;;;;;;;;;;;;;;
 (define (DenemoFirst)
   (begin
@@ -883,3 +1015,148 @@
      (d-DirectivePut-paper-postfix "PrintAllHeaders" (string-append lily " = ##t\n"))))
 
 
+
+;;;; Move right until "appending" or "none" which is the Measure End
+(define (GoToMeasureEnd)
+
+(let loop ()
+    (if  (or (string-ci=?  (d-GetType) "none") (string-ci=?  (d-GetType) "appending"))
+	#t
+	(begin (d-MoveCursorRight) (loop))))
+		
+)
+
+
+;;;;;;;;;;;;;;;;;;;; Paste by Nils Gey // 2010
+; Multistaff-Pasting always adds the complete part AFTER the current measure. It will never paste into an existing measure, not even in empty ones. 
+; Singlestaff-Pasting happens at the cursor position. If there are still notes in the current measure, after the cursor position, those will be shoved to the right and placed after the pasted section, no matter if the result produce underful or overful measures. No other measure gets modified other than the current one. Singlestaff-Pasting will fill any empty measure on its way, until a non-empty one is encountered. For snippet pasting (< one full measure) it will automatically create new measures if needed. 
+(define (DenemoPaste)
+(let pasteblock ((paste::break? (Paste::MeasureBreakInClipboard?)))
+
+(d-UnsetMark)
+(d-PushPosition) 
+
+;Multi staff selection is only possible for complete measures, not for parts. But In this case the first thing that needs to happen before beginning pasting to a new staff (including the first one) is to create an empty measure.
+
+(if (d-GetClipObjType 1 0)
+	(d-InsertMeasureAfter) ; Multistaff
+)
+
+ ; Add an initial empty measure if pasting single-staff multi-measure and the current measure is already full
+
+(if (and paste::break? (string-ci=? (d-GetType) "Appending")  (d-GetClipObjType 0 0) (not (d-GetClipObjType 1 0)) (MeasureFillStatus)   )
+        (if (d-MoveToMeasureRight) ; End of Staff?
+			(if (MeasureEmpty?) 
+				#t
+				(d-InsertMeasureBefore) ) 
+			(d-InsertMeasureAfter)))
+
+
+; If a user wants to paste a multi-measure section between two objects the remaining objects (after the cursor -> until the next barline) need to put in an extra measure. d-SplitMeasure takes care of that.
+; The conditions that need to met are quite a few:
+	(if (and 
+	(d-GetClipObjType 0 0) ; Check if there is a clipboard at all. 
+	(not (d-GetClipObjType 1 0)) ; Only for single-staff
+	(not (or (string-ci=?  (d-GetType) "none") (string-ci=?  (d-GetType) "Appending"))) ; Check if its the right position to split. There must be notes left in the measure. GetType returns "none" if its an empty measure  or "Appending" if there are no objects left until the next measure.
+       paste::break?  ; If there is no measurebreak there is no need to split
+	) 
+		(d-SplitMeasure)
+		#f)
+
+
+;;;;;;;;;;;;;;;;;;;;;;;
+;;;;;; Main Loop ;;;;;; 
+;;;;;;;;;;;;;;;;;;;;;;;
+
+ (let loopy ((staff 0) (count 0))
+  ;Pasty is the default command which just inserts the clipboard-object and increases the object-counter, but does not touch the staff-counter
+  (define (pasty)
+  	(d-PutClipObj staff count)
+  	(set! count (+ 1 count))
+  	(loopy staff count))
+
+ ; Nextplease increases the object-counter without pasting anything.
+  (define (nextplease)
+	(set! count (+ 1 count))
+  	(loopy staff count))
+ 
+ ;Nextstaff inserts a new measure only in this new staff! It is not possible to add a measure in all staffs because its possible to copy&paste only 2 out of n staffs. In such cases it would lead to empty measure in other staffs. Afterwards reset the object-counter to zero and increase the staff-counter to start a new pasting round.
+;First go to the initial cursor position, then move staff down.
+ (define (nextstaff)
+   (if (= staff 0)  
+          (d-PopPushPosition) ; remember the  end-position of the cursor only for the first staff to return there after paste
+ 	  (d-PopPosition)
+    )
+
+   (if (d-MoveToStaffDown) 
+	(begin	(d-InsertMeasureAfter)
+			(d-PushPosition) 
+			(set! count 0)
+			(set! staff (+ 1 staff))
+		  	(loopy staff count))
+  	(begin  (d-PopPosition) (d-MoveCursorRight) (display "Paste: Not possible to go a staff down, pasting whats possible.\n") #f) ; Warn about not enough staffs to paste in and place the cursor after the pasted section (duplicate of case -1)
+    )
+  )
+  
+ (define (measurebreak)
+ 
+   (if (d-GetClipObjType 1 0) ;Multistaff?
+	(begin (d-InsertMeasureAfter) (nextplease))  ;Yes it is, just go on and paste
+      
+        (if  (and (not (d-GetClipObjType 1 0)) (= 8 (d-GetClipObjType 0 0)) (= 0 count)) ; User might have copied a leading measurebreak by accident. Ignore this. Else go on and try to detect empty measures or add measures.
+		(nextplease)
+		(if (d-MoveToMeasureRight) ; End of Staff?
+			(if (MeasureEmpty?) (nextplease) (begin (d-InsertMeasureBefore) (nextplease))) ;
+			(begin (d-InsertMeasureAfter) (nextplease))))
+)) 
+
+; In the end move cusor to the initial staff, after the pasted part to allow direct pasting and editing again.
+ (define (endthis)
+ 	(if (> staff 0) 
+		(begin (d-PopPosition) (d-PopPosition) ))
+	
+	;This was needed at some type, after an (unrelated?) upgrade of the script it was not needed anymore.  Better keep it in...
+	;(if (d-GetClipObjType 0 0) (d-MoveCursorRight)) ; Only move cursor right if there was a clipboard to paste.
+	(d-RefreshDisplay)
+	#t
+ )
+  
+  
+ ; For clipboards smaller than one full measure Denemo will automatically add barlines if needed 
+ (if (and (d-GetClipObjType staff count) (string-ci=?  (d-GetType) "Appending")  (not paste::break?) (MeasureFillStatus))
+            (if (d-MoveToMeasureRight) ; End of Staff?
+			(if (MeasureEmpty?) 
+				#t
+				(d-InsertMeasureBefore) ) 
+			(d-InsertMeasureAfter)))
+ 
+  
+; The real action: Get the type of clipboard-object and decide what to do. In most cases it will be just pasting but someties special behaviour is needed. Because pasting a staffbreak does not actually moves the cursor to the new staff so this has to be done manually.
+ (case (d-GetClipObjType staff count) 
+	((#f) (endthis) ) ; No object left. Means "no clipboard", too.
+	((-1) (display "No object")); should not happen anymore
+	((0) (pasty)) ; note, rest, gracenote, chord
+	((1) (pasty)) ;tuplet open
+	((2) (pasty)) ;tuplet close
+	((3) (pasty)) ; Clef
+	((4) (pasty)) ;Timesignature
+	((5) (pasty)) ;Keysignature
+	((6) (display "barline"))
+	((7) (pasty))	;stem directive
+	((8) (measurebreak) ) ; Measurebreak
+	((9) (nextstaff) ) ; staffbreak 
+	((10) (display "dynamic"))	
+	((11) (display "grace start")) ;deprecated
+	((12) (display "grace end")) ;deprecated
+	((13) (display "lyric")) ;deprecated
+	((14) (display "figure")) 
+	((15) (pasty)) ; Lilypond-Directive
+	((16) (display "fakechord"))				
+	((17) (display "partial"))
+	(else (begin (display "Error! Object to paste unknown\n") #f))
+   )
+ ) 
+ ))
+ 
+ ;;;;;;;;;;;;;;;;;;;;;;;; Paste End
+
