@@ -341,6 +341,7 @@ typedef struct DenemoPrefs
   GString *audioplayer; /**< This is used for playing audio files created from csound or other */
   gboolean playbackoutput; /**< This is a switch to turn on playing the csound output 
 			     wav file after rendering or not */
+  GString *shortcut_filename; /**< file containing shortcuts for actions */
   gboolean immediateplayback; /**< This options sends audio directly to synth as notes 
 				are being entered */
   gboolean startmidiin; /**< try to start midi in on startup */
@@ -350,9 +351,10 @@ typedef struct DenemoPrefs
   gboolean lilyentrystyle;  
   gboolean createclones;
   gint mode; /**< mode to start in */
-
+  gboolean modal;/**< whether mode-switching menu is desired */
   gint zoom; /**< percent zoom  1-100 */
   gint system_height; /**< percent of display height per system  1-100 */
+  gboolean cursor_highlight; /** Should the cursor be highlighted */
 
   gboolean playback_controls; /**< makes the playback controls visible */
   gboolean midi_in_controls; /**< makes the midi in controls visible */
@@ -392,7 +394,7 @@ typedef struct DenemoPrefs
   gint fluidsynth_period_size;/**< The size of the audio buffers (in frames).> */
 
   gdouble display_refresh;/**< time in ms between refresh of display during playback */
-
+  gint animation_steps;/** < number of steps to use animating the page turns during playback */
   GString *pdfviewer; /**< PDF viewer */
   GString *imageviewer; /**< Image Viewer */
   GString *username; /**< Username for use on denemo.org website */
@@ -403,7 +405,9 @@ typedef struct DenemoPrefs
 
   GString *lilyversion; /**< Lilypoind Version */
   GString *temperament; /**< Preferred temperament for tuning to */
-  gboolean strictshortcuts; /**< Whether shortcuts require CaspLock & NumLock to be correct */
+  gboolean strictshortcuts; /**< Classic shortcut scheme, now deprecated */
+  gboolean verboseshortcuts; /**< whether shortcuts are known by their gdk name e.g. period for . */
+  
   gint resolution; /**< Resolution of exported selection in dpi */
 }DenemoPrefs;
 
@@ -524,6 +528,12 @@ typedef enum MidiDestination {
   MIDIRECORD = (1<<2),
 } MidiDestination;
 
+typedef enum DenemoViewType {
+  DENEMO_MENU_VIEW,//menus are visible
+  DENEMO_LINE_VIEW,//menus not visible, 
+  DENEMO_PAGE_VIEW //menus not visible, defaults to full screen and several systems
+} DenemoViewType;
+
 
 /**
  * Structure to contain the list of Instruments for the score
@@ -605,6 +615,8 @@ typedef struct DenemoPosition { /**<Represents a position in a Score */
   gint staff;
   gint measure;
   gint object;/**< 0 means no object */
+  gboolean appending;/**< if cursor is in appending position */
+  gboolean offend;/**< cursor is shown red in this case, obscure connection with appending */
 } DenemoPosition;
 
 
@@ -677,8 +689,18 @@ typedef struct DenemoScore
   gdouble master_tempo;/**< the tempo used is this times the nominal tempo */
   gdouble tempo_change_time;/**< system time from which the master_tempo is to be used */
   gdouble rightmost_time; /**< MIDI time of rightmost visible object */
-  gdouble zoom;
-  gdouble system_height;/**< fraction of scorearea height allotted to one system (line) in the score, the same for all lines */
+
+  gdouble zoom;/**< zoom setting for this movement */
+  gdouble system_height;/**< fraction of scorearea height allotted to one system (line) in this movement of the score, the same for all lines */
+  //Settings for the views on this movement
+
+  gdouble page_zoom;/**< zoom for page view */
+  gdouble page_system_height;/**< system height for page view */ 
+  gint page_width;/**< width to use for window in page view. 0 means use full screen */
+  gint page_height;/**< height to use for window in page view */
+  gint stored_width;/**< width to use for window returning from page view */
+  gint stored_height;/**< height to use for window returning from page view */
+
   /* Fields that have more to do with the data model and its manipulation,
    * though they may be modified by side-effects of the drawing routines */
   // score thescore;
@@ -782,6 +804,7 @@ typedef struct DenemoGUI
   GtkWidget *vscrollbar;
   GtkObject *hadjustment;
   GtkWidget *hscrollbar;
+  DenemoViewType view;/**< The current view */
 #define DENEMO_MAX_SYSTEMS (100) /**< Number of lines of music that can be displayed */
   gint lefts[DENEMO_MAX_SYSTEMS];/**< an array to hold the leftmeasurenum of each system in the last-drawn score, used for determining the mouse position on the music */
   gint rights[DENEMO_MAX_SYSTEMS];/**< an array to hold the rightmeasurenum of each system in the last-drawn score, used for determining the mouse position on the music */
@@ -849,6 +872,7 @@ typedef struct RhythmPattern
 {
   GList *rsteps; /**< the data are RhythmElements */
   GtkToolButton *button; /**< the button on the rhythm toolbar which invokes this rhythm */
+  GList *clipboard;/**< a Denemo clipboard, used to create this patttern. */
 } RhythmPattern;
 
 
