@@ -289,6 +289,8 @@ object_insert (DenemoGUI * gui, DenemoObject * mudela_obj_new)
 
   declarecurmudelaobj;
 
+#if 0
+  //this makes writing scripts difficult, and anyway assumes Denemo knows where the barlines are
   /* First, check to see if the operation would add something before an
    * indicator of a time signature change. This would be bad, so don't
    * allow it to happen */
@@ -300,24 +302,10 @@ object_insert (DenemoGUI * gui, DenemoObject * mudela_obj_new)
       else
 	si->cursor_appending = TRUE;
     }
-
+#endif
   si->currentmeasure->data =
     g_list_insert ((objnode *) si->currentmeasure->data,
 		   mudela_obj_new, si->cursor_x);
-#if 0
-  if(mudela_obj_new->type == CHORD) {
-    chord *newchord = (chord *) mudela_obj_new->object;
-there is a function newclefify and fixnoteheights...
-    if(newchord->notes){
-      gint dclef = find_prevailing_clef(si);
-      newchord->lowesty = calculateheight (newchord->lowestpitch, dclef);
-      newchord->highesty = calculateheight (newchord->highestpitch, dclef);
-      newchord->stemy = calculateheight (stemoffset, dclef);
- beamsandstemdirswholestaff is the only thing I think???
-    }
-  }
-#endif
-
 
   if(mudela_obj_new->type == CLEF) {
 	  reset_cursor_stats (si);
@@ -940,6 +928,51 @@ cursordown (DenemoScriptParam *param)
   //g_print ("Cursor Y Position %d\n", gui->si->cursor_y);
 }
 
+static gboolean prev_object_is_rhythm (DenemoGUI *gui) {
+  if(gui->si->currentobject==NULL)
+    return FALSE;
+  return  ((DenemoObject *)(gui->si->currentobject->data))->isinvisible;
+}
+
+
+/* insert a note into the score at the current cursor position following the current rhythm step */
+
+void insert_note(DenemoGUI *gui)  {
+#define g  (gui->rstep)
+  if((gui->mode&(INPUTEDIT|INPUTINSERT)) && g) {
+    GList *start = g;
+    GList *h;
+
+
+    gint mode = gui->mode;
+    gui->mode = mode & ~INPUTRHYTHM;
+
+    do {
+      if(g) {
+	for(h = ((RhythmElement*)g->data)->functions;h;h=h->next) {
+	  insertion_point (gui->si);	
+	  gui->si->cursoroffend = FALSE;
+	  ((GtkFunction)h->data)(gui);
+	  displayhelper(gui);
+	}
+	h = ((RhythmElement*)g->data)->functions;
+	g = g->next;/* list is circular */
+      }
+    } while(g!=start && modifier_code(h->data));
+#define CURRP ((RhythmPattern *)gui->currhythm->data)    
+    if(((RhythmElement*)g->data)->icon) {/* singletons do not have icon */
+      GtkWidget *label = LABEL(CURRP->button);
+      //g_print("Markup is %s\n", ((RhythmElement*)g->data)->icon);
+      gtk_label_set_markup(GTK_LABEL(label),((RhythmElement*)g->data)->icon);
+    }
+    gui->mode = mode;
+    score_status(gui, TRUE);
+  }
+#undef CURRP
+#undef g
+}
+
+
 /**
  * shiftcursor: FIXME change the name of this function!
  * Mode sensitive note actions:
@@ -958,16 +991,18 @@ shiftcursor (DenemoGUI  *gui, gint note_value)
   int mid_c_offset = gui->si->cursor_y;
      
   /* in edit mode edit the current note name */
-  if((gui->mode & INPUTEDIT) && gui->si->currentobject) {
+  if((gui->mode & INPUTEDIT) &&
+     ( (!gui->si->cursor_appending) ||
+       prev_object_is_rhythm(gui))) {
     DenemoObject *theobj =  (DenemoObject *)(gui->si->currentobject->data);
     chord *thechord;
     if(theobj->type == CHORD && (thechord = (chord*)theobj->object)->notes) {
       theobj->isinvisible=FALSE;
       if(g_list_length(thechord->notes)>1) {/* multi-note chord - remove and add a note */
 	gui->si->cursor_y = oldcursor_y;
-	delete_chordnote(gui->si);
+	delete_chordnote(gui);
 	gui->si->cursor_y = mid_c_offset;
-	insert_chordnote (gui->si);
+	insert_chordnote (gui);
       } else {/* single-note chord - change the note */
       gint dclef = find_prevailing_clef(gui->si);	    
       modify_note(thechord, mid_c_offset, gui->si->curmeasureaccs[note_value], dclef);
@@ -977,38 +1012,15 @@ shiftcursor (DenemoGUI  *gui, gint note_value)
       score_status(gui, TRUE);
     }  
   } else
-    /* in INSERT (or EDIT with no currentobject) we insert a note using the next step of the rhythm pattern */
-#define g  (gui->rstep)
-  if((gui->mode&(INPUTEDIT|INPUTINSERT)) && g) {
-      GList *start = g;
-      GList *h;
-      do {
-	if(g) {
-	  for(h = ((RhythmElement*)g->data)->functions;h;h=h->next) {
-	    insertion_point (gui->si);	
-	    gui->si->cursoroffend = FALSE;
-	    ((GtkFunction)h->data)(gui);
-	    displayhelper(gui);
-	  }
-	  h = ((RhythmElement*)g->data)->functions;
-	  g = g->next;/* list is circular */
-	}
-      } while(g!=start && modifier_code(h->data));
-#define CURRP ((RhythmPattern *)gui->currhythm->data)    
-      if(((RhythmElement*)g->data)->icon) {/* singletons do not have icon */
-	GtkWidget *label = LABEL(CURRP->button);
-	//g_print("Markup is %s\n", ((RhythmElement*)g->data)->icon);
-	gtk_label_set_markup(GTK_LABEL(label),((RhythmElement*)g->data)->icon);
-      }
-      score_status(gui, TRUE);
-    }
-#undef CURRP
-#undef g
+    /* in INSERT (or EDIT and appending) we insert a note using the next step of the rhythm pattern */
+    insert_note(gui);
+
 }
 
 
 void
 insert_rhythm_pattern(DenemoGUI  *gui) {
+#if 0
 #define g  (gui->rstep)
   if((gui->mode&(INPUTEDIT)) && g) {
     GList *start = g;
@@ -1031,6 +1043,12 @@ insert_rhythm_pattern(DenemoGUI  *gui) {
     } while(g!=start);
   }
 #undef g
+#else
+
+  if(gui->currhythm==NULL)
+    return;
+  insert_clipboard(((RhythmPattern *)gui->currhythm->data)->clipboard);
+#endif
 }
 
 /**
@@ -1102,7 +1120,7 @@ dnm_insertchord (DenemoGUI * gui, gint duration, input_mode mode,
   int prognum;
   
 
-  if((mode & INPUTEDIT) && !si->cursor_appending && !(mode & INPUTRHYTHM)) {
+  if((mode & INPUTEDIT) && !si->cursor_appending && !(mode & INPUTRHYTHM) ) {
     changeduration(si, duration);
     return;
   }
@@ -1120,7 +1138,7 @@ dnm_insertchord (DenemoGUI * gui, gint duration, input_mode mode,
      added a measure above, object_insert will invoke nudgerightward,
      which will in turn invoke update_hscrollbar, so we
      don't need to invoke that here.  */
-
+  gboolean was_appending = si->cursor_appending;
   object_insert (gui, mudela_obj_new);
  
   if (gui->mode&(INPUTRHYTHM)) {
@@ -1133,7 +1151,8 @@ dnm_insertchord (DenemoGUI * gui, gint duration, input_mode mode,
       else
 	playpitch(64.0*(1+duration), 60.0/(gui->si->tempo*(1<<duration)), 0.2, 1);
 #endif
-
+    if(!was_appending)
+      movecursorleft(NULL);
 
   } else {
     if(Denemo.gui->last_source==INPUTKEYBOARD) {
@@ -1279,16 +1298,20 @@ notechange (DenemoScore * si, gboolean remove)
  * Delete chord note closest to y cursor
  */
 gboolean
-delete_chordnote (DenemoScore * si){
-  notechange(si, TRUE);
+delete_chordnote (DenemoGUI * gui){
+  notechange(gui->si, TRUE);
   return TRUE;
 }
 /**
  * Insert chord note at y cursor position 
  */
 gboolean
-insert_chordnote (DenemoScore *si){
-  notechange(si, FALSE);
+insert_chordnote (DenemoGUI *gui){
+ DenemoObject *curObj;
+  if(gui->si->currentobject && (curObj = Denemo.gui->si->currentobject->data) && (curObj->type==CHORD) )
+    notechange(gui->si, FALSE);
+  else
+    insert_note(gui);
   return TRUE;
 }
 
@@ -1817,15 +1840,20 @@ dnm_deleteobject (DenemoScore * si)
 	  find_xes_in_all_measures (si);
 	  break;
 	case TIMESIG:
-	  /* For time signatures, deletion is linked to all
-	   * the staffs on the score */
+	  delete_object_helper (si);
+	  /* For time signature changes remove from all other staffs 
+	   * if in the conventional, first, position */
 	  for (curstaff = si->thescore; curstaff; curstaff = curstaff->next)
 	    {
 	      curmeasure = g_list_nth (firstmeasurenode (curstaff),
 				       si->currentmeasurenum - 1);
-	      if(curmeasure){
-		remove_object (curmeasure, (objnode *) curmeasure->data);
-		beamsandstemdirswholestaff ((DenemoStaff *) curstaff->data);
+	      if(curmeasure && curmeasure->data){
+		DenemoObject *first_obj = ((objnode *) curmeasure->data)->data;
+		//g_print("Deleting object of type %s\n", DenemoObjTypeNames[first_obj->type]);
+		if(first_obj && first_obj->type == TIMESIG) {
+		  remove_object (curmeasure, (objnode *) curmeasure->data);
+		  beamsandstemdirswholestaff ((DenemoStaff *) curstaff->data);
+		}
 	      }
 	    }
 	  reset_cursor_stats (si);
@@ -1933,6 +1961,7 @@ gotoend (gpointer param, gboolean extend_selection)
     cursorright(param);
   else
     movecursorright(param);
+scorearea_expose_event(NULL, NULL);//refresh cached values, eg current timesig
   find_leftmost_allcontexts (gui->si);
   update_hscrollbar (gui);
   displayhelper (gui);
@@ -1956,6 +1985,7 @@ gotohome (gpointer param, gboolean extend_selection)
   find_leftmost_allcontexts (gui->si);
   update_hscrollbar (gui);
   /*gtk_widget_draw (gui->scorearea, NULL);*/
+  scorearea_expose_event(NULL, NULL);//refresh cached values, eg current timesig
   gtk_widget_queue_draw (gui->scorearea);
 }
 
