@@ -22,6 +22,7 @@ void
 draw_cursor (cairo_t *cr, DenemoScore * si,
 	     gint xx, gint y, input_mode mode, gint dclef)
 {
+  if(!cr) return;
   gint height = calculateheight (si->cursor_y, dclef);
 
   static GdkGC *blackgc = NULL;
@@ -50,6 +51,16 @@ draw_cursor (cairo_t *cr, DenemoScore * si,
   setcairocolor( cr, paintgc );
   cairo_rectangle( cr, xx, height + y - CURSOR_MINUS, CURSOR_WIDTH, CURSOR_HEIGHT );
   cairo_fill( cr );
+  if(Denemo.prefs.cursor_highlight) {
+    gdouble length = 40/si->zoom;
+    cairo_set_line_width (cr, 6.0/si->zoom);
+    cairo_set_source_rgba (cr, 0, 1, 0, 0.60);
+    cairo_move_to( cr, xx+ CURSOR_WIDTH/2 - length/2, height + y - length/2);
+    cairo_rel_line_to( cr, length, length);
+    cairo_rel_move_to( cr, 0, -length);
+    cairo_rel_line_to( cr, -length, length);
+    cairo_stroke( cr );
+  }
   cairo_restore( cr );
 
   /* Now draw ledgers if necessary and we're done */
