@@ -289,6 +289,9 @@ determineclef (gint type, gchar ** clefname)
     case DENEMO_SOPRANO_CLEF:
       *clefname = "soprano";
       break;
+    case DENEMO_FRENCH_CLEF:
+      *clefname = "french";
+      break;
     default:
       *clefname = _("%{error. defaulting to%}treble");
       break;
@@ -1425,6 +1428,7 @@ outputStaff (DenemoGUI *gui, DenemoScore * si, DenemoStaff * curstaffstruct,
     g_string_prepend(figures_name, "Figured Bass for ");
     g_string_append_printf(figures_name, " Voice %d", voice_count);
     insert_music_section(gui, figures_name->str);
+    g_string_append(figures, "%figures follow\n");
   }
   /* a button and mark for the chord symbols of this staff */
   GString *fakechords_name = g_string_new(movement);
@@ -1432,6 +1436,7 @@ outputStaff (DenemoGUI *gui, DenemoScore * si, DenemoStaff * curstaffstruct,
     g_string_prepend(fakechords_name, "Chord symbols for ");
     g_string_append_printf(fakechords_name, " Voice %d", voice_count);
     insert_music_section(gui, fakechords_name->str);
+    g_string_append(fakechords, "%chord symbols follow\n");
   }
 
   gtk_text_buffer_get_iter_at_mark(gui->textbuffer, &iter, curmark);
@@ -2241,7 +2246,7 @@ output_score_to_buffer (DenemoGUI *gui, gboolean all_movements, gchar * partname
 	      }
 
 	      if (curstaffstruct->hasfigures)
-		g_string_append_printf(staffdefinitions, TAB TAB" \\context FiguredBass \\%s%sBassFiguresLine\n", movement_name->str, voice_name->str);
+		g_string_append_printf(staffdefinitions, TAB TAB" \\context FiguredBass \\with {implicitBassFigures = #'(0) } \\%s%sBassFiguresLine\n", movement_name->str, voice_name->str);
 	      g_string_append_printf(staffdefinitions, TAB TAB"%s\n", endofblock);
 	    }
 	  else if (curstaffstruct->voicenumber == 2)
@@ -2500,7 +2505,8 @@ lily_save(GtkWidget *item, GdkEventCrossing *e, DenemoGUI *gui){
   if(gui->textwindow) {
     g_signal_handlers_unblock_by_func (G_OBJECT (gui->textwindow), G_CALLBACK (lily_refresh), gui);
     merge_lily_strings(gui);
-    gtk_widget_queue_draw (gui->scorearea);
+    if(gui->si)
+      scorearea_expose_event(NULL, NULL);//!gtk_widget_queue_draw (gui->scorearea);
   }
   return FALSE;
 }
