@@ -29,6 +29,8 @@
 #include "binreloc.h"
 #include "view.h"
 #include "lilydirectives.h"
+#include "texteditors.h"
+#include "print.h"
 #include <stdio.h>
 #include <string.h>
 #include <sys/stat.h>		/* check existance and type of files */
@@ -36,7 +38,7 @@
 
 
 
-static gboolean
+static gint
 file_open (DenemoGUI * gui, gboolean template, ImportType type, gchar *filename);
 
 
@@ -229,12 +231,13 @@ open_for_real (gchar * filename, DenemoGUI * gui, gboolean template, ImportType
 {
   g_signal_handlers_block_by_func(G_OBJECT (gui->scorearea), G_CALLBACK (scorearea_expose_event), NULL);
   gint result;
+  gboolean xml = FALSE;
   result = 1;//FAILURE
   if(g_file_test(filename, G_FILE_TEST_EXISTS)) {
     if (strcmp (filename + strlen (filename) - 7, ".denemo") == 0)
-      result = importXML (filename, gui, type);
+      xml=TRUE, result = importXML (filename, gui, type);
     else if (strcmp (filename + strlen (filename) - 4, ".dnm") == 0)
-      result = importXML (filename, gui, type);
+      xml=TRUE, result = importXML (filename, gui, type);
     else if (strcmp (filename + strlen (filename) - 3, ".ly") == 0)
       result = lyinput (filename, gui);
     else if (strcmp (filename + strlen (filename) - 4, ".mid") == 0 ||
@@ -253,7 +256,8 @@ open_for_real (gchar * filename, DenemoGUI * gui, gboolean template, ImportType
 	g_string_assign (gui->filename, "");
       if(gui->printarea) 
 	g_object_set_data(G_OBJECT(gui->printarea), "printviewupdate", (gpointer)G_MAXUINT);
-      updatescoreinfo (gui);
+      if(!xml)
+	updatescoreinfo (gui);
       set_rightmeasurenum (gui->si);
       select_lyrics();
       set_bottom_staff (gui);
@@ -456,7 +460,7 @@ typedef enum {
  * does nothing if unable to access templates
  * filename is NULL for interactive use, otherwise file base name
  */
-static gboolean
+static gint
 template_open (DenemoGUI * gui, TemplateType local, gchar *filename)
 {
   gboolean ret = FALSE;
@@ -509,12 +513,12 @@ system_template_open_with_check (GtkAction * action, DenemoScriptParam * param)
     {
       if (filename==NULL && confirmbox (gui))
 	{
-	  param->status = template_open (gui, SYSTEM, filename);
+	  param->status = !template_open (gui, SYSTEM, filename);
 	}
     }
   else
     {
-      param->status = template_open (gui, SYSTEM, filename);
+      param->status = !template_open (gui, SYSTEM, filename);
     }
 }
 
@@ -529,12 +533,12 @@ system_example_open_with_check (GtkAction * action, DenemoScriptParam * param) {
     {
       if (confirmbox (gui))
 	{
-	  param->status = template_open (gui, EXAMPLE, filename);
+	  param->status = !template_open (gui, EXAMPLE, filename);
 	}
     }
   else
     {
-      param->status = template_open (gui, EXAMPLE, filename);
+      param->status = !template_open (gui, EXAMPLE, filename);
     }
 }
 /*
@@ -548,12 +552,12 @@ local_template_open_with_check (GtkAction * action, DenemoScriptParam * param) {
     {
       if (filename==NULL && confirmbox (gui))
 	{
-	  param->status = template_open (gui, LOCAL, filename);
+	  param->status = !template_open (gui, LOCAL, filename);
 	}
     }
   else
     {
-      param->status = template_open (gui, LOCAL, filename);
+      param->status = !template_open (gui, LOCAL, filename);
     }
 }
 
@@ -577,7 +581,7 @@ file_open_with_check (GtkAction * action, DenemoScriptParam * param)
   if (!gui->notsaved ||  (gui->notsaved && (confirmbox (gui))))
     {
       //deletescore (NULL, gui);
-      param->status = file_open (gui, FALSE, REPLACE_SCORE, filename);
+      param->status = !file_open (gui, FALSE, REPLACE_SCORE, filename);
     }
 }
 
@@ -592,7 +596,7 @@ file_add_movements(GtkAction * action,  DenemoScriptParam * param){
   GET_1PARAM(action, param, filename);
   if(filename==NULL && !confirm_insertstaff_custom_scoreblock(gui))
     return;
-  param->status = file_open(gui, FALSE, ADD_MOVEMENTS, filename);
+  param->status = !file_open(gui, FALSE, ADD_MOVEMENTS, filename);
   score_status(gui, TRUE);
 }
 /**
@@ -605,7 +609,7 @@ file_add_staffs(GtkAction * action,  DenemoScriptParam * param){
   DenemoGUI *gui = Denemo.gui;
   if(filename==NULL && !confirm_insertstaff_custom_scoreblock(gui))
     return;
-   param->status = file_open(gui, FALSE, ADD_STAFFS, filename);
+   param->status = !file_open(gui, FALSE, ADD_STAFFS, filename);
   score_status(gui, TRUE);
 }
 
@@ -634,15 +638,15 @@ static void  set_current_folder(GtkWidget *file_selection, DenemoGUI *gui, gbool
 }
 /**
  * File open dialog - opened where appropriate 
- * return TRUE on success FALSE on failure.
+ * return 0 on success non-zero on failure.
  * filename must be full path or NULL for dialog
  */
-static gboolean
+static gint
 file_open (DenemoGUI * gui, gboolean template, ImportType type, gchar *filename)
 {
-  gboolean ret = FALSE;
+  gboolean ret = -1;
   if(filename && !g_file_test(filename, G_FILE_TEST_IS_DIR))
-    return (0==open_for_real(filename, gui, template, type));
+    return (open_for_real(filename, gui, template, type));
 
   GtkWidget *file_selection;
   GtkFileFilter *filter;
