@@ -3,6 +3,7 @@
 AJAnderson
 
 */
-
+#include "smf.h"
+gint process_track(smf_track_t *track);
 gint importMidi(gchar * filename, DenemoGUI *gui);
 
