@@ -479,6 +479,8 @@ parseClef (xmlNodePtr clefElem, xmlNsPtr ns, clef * clef)
     clef->type = DENEMO_TENOR_CLEF;
   else if (strcmp (clefTypeName, "soprano") == 0)
     clef->type = DENEMO_SOPRANO_CLEF;
+  else if (strcmp (clefTypeName, "french") == 0)
+    clef->type = DENEMO_FRENCH_CLEF;
   else
     {
       g_warning ("Unknown clef type \"%s\"; defaulting to treble",
@@ -869,6 +871,7 @@ static DenemoObject *
 parseBaseChord (xmlNodePtr chordElem, xmlNsPtr ns, DenemoScore * si)
 {
   xmlNodePtr durationElem, dotsElem;
+  xmlNodePtr childElem;
   gboolean successful = FALSE;
   gchar *durationType;
   gint baseDuration = 2, numDots = 0;
@@ -955,6 +958,28 @@ DenemoObject *chordObj =
   show?newchord (baseDuration, numDots, 0):hidechord(newchord (baseDuration, numDots, 0));
  if(grace)
    ((chord *) chordObj->object)->is_grace = GRACED_NOTE;
+
+
+  FOREACH_CHILD_ELEM (childElem, chordElem)  {
+    if (childElem->ns == ns) {
+      if (ELEM_NAME_EQ (childElem, "directives"))  {
+	((chord *) chordObj->object)->directives = parseDirectives(childElem, ns);	  
+      }
+      else if (ELEM_NAME_EQ (childElem, "figure"))
+	{
+	  parseFigure (childElem, chordObj);
+	  si->has_figures = (gpointer) TRUE;
+	}
+      else if (ELEM_NAME_EQ (childElem, "fakechord"))
+	{
+	  parseFakechord (childElem, chordObj);
+	  si->has_fakechords = (gpointer) TRUE;
+	}
+    }
+  }
+  
+
+
  return chordObj;
 }
 
@@ -970,13 +995,7 @@ parseRest (xmlNodePtr restElem, xmlNsPtr ns, DenemoScore * si)
 
   chordObj = parseBaseChord (restElem, ns, si);
 
-  FOREACH_CHILD_ELEM (childElem, restElem)  {
-    if (childElem->ns == ns) {
-      if (ELEM_NAME_EQ (childElem, "directives"))  {
-	((chord *) chordObj->object)->directives = parseDirectives(childElem, ns);	  
-      }
-    }
-  }
+
   return chordObj;
 }
 
@@ -1404,20 +1423,8 @@ parseChord (xmlNodePtr chordElem, xmlNsPtr ns,
 	  {
 	    parseLyric (childElem, chordObj);
 	  }
-	else if (ELEM_NAME_EQ (childElem, "figure"))
-	  {
-	    parseFigure (childElem, chordObj);
-	    si->has_figures = (gpointer) TRUE;
-	  }
-	else if (ELEM_NAME_EQ (childElem, "fakechord"))
-	  {
-	    parseFakechord (childElem, chordObj);
-	    si->has_fakechords = (gpointer) TRUE;
-	  }
-	else if (ELEM_NAME_EQ (childElem, "directives")) 
-	  {
-	  ((chord *) chordObj->object)->directives = parseDirectives(childElem, ns);	  
-	  }
+
+	
 	//Support for old files 0.8.2 only
 #define DO_DIREC(field) else if (ELEM_NAME_EQ (childElem, #field))\
 	  {\
@@ -1440,10 +1447,17 @@ parseChord (xmlNodePtr chordElem, xmlNsPtr ns,
 	    ((chord *) chordObj->object)->chordize = TRUE;
 	  }
 
-
-
-
-
+	else if (ELEM_NAME_EQ (childElem, "directives"))  {
+	  ;//done in base
+	}
+	else if (ELEM_NAME_EQ (childElem, "figure"))
+	  {
+	    ;//done in base
+	  }
+	else if (ELEM_NAME_EQ (childElem, "fakechord"))
+	  {
+	    ;//done in base
+	  }
 	else
 	  {
 	    ILLEGAL_ELEM ("chord", childElem);
@@ -1753,6 +1767,26 @@ parseEditInfo (xmlNodePtr editInfoElem, xmlNsPtr ns, DenemoScore * si)
 	  {
 	    si->system_height = getXMLIntChild (childElem)/100.0;
 	    if(si->system_height < 0.01) si->system_height = 1.0;
+	  }	
+	else if (ELEM_NAME_EQ (childElem, "page-zoom"))
+	  {
+	    si->page_zoom = getXMLIntChild (childElem)/100.0;
+	    if(si->page_zoom < 0.01) si->page_zoom = 1.0;
+	  }
+	else if (ELEM_NAME_EQ (childElem, "page-system-height"))
+	  {
+	    si->page_system_height = getXMLIntChild (childElem)/100.0;
+	    if(si->page_system_height < 0.01) si->page_system_height = 1.0;
+	  }
+	else if (ELEM_NAME_EQ (childElem, "page-width"))
+	  {
+	    si->page_width = getXMLIntChild (childElem);
+	    if(si->page_width < 0) si->page_width = 0;
+	  }
+	else if (ELEM_NAME_EQ (childElem, "page-height"))
+	  {
+	    si->page_height = getXMLIntChild (childElem);
+	    if(si->page_height < 0) si->page_height = 0;
 	  }
 
 
@@ -2707,7 +2741,7 @@ static gint   parseMovement(xmlNodePtr childElem, xmlNsPtr ns, DenemoGUI *gui, I
   si->currentmeasurenum = current_measure?current_measure:1;
   si->currentstaff = g_list_nth(si->thescore, current_staff-1);
   setcurrents(si);
-  si->cursor_x = current_position + 1;
+  si->cursor_x = current_position;
   si->currentobject = (objnode *)g_list_nth(si->currentmeasure->data, si->cursor_x);
   
   if (!si->currentobject)
