@@ -37,11 +37,11 @@
 #endif
 
 
-#ifdef G_OS_WIN32
-#define DEFAULT_KEYMAP "Windows.cmdset"
-#else
-#define DEFAULT_KEYMAP "Default.cmdset"
-#endif
+
+#define DEFAULT_KEYMAP "Default.commands"
+
+#define DEFAULT_COMMANDS "Default.commands"
+#define DEFAULT_KEYBINDINGS "Default.shortcuts"
 
 //index of columns in the keymap command list store FIXME if you add columns you must add them in keymap_get_command_row and allocate_keymap !!!!
 enum {
@@ -72,6 +72,22 @@ typedef struct command_row {
 static void
 load_keymap_file_named (gchar *keymapfile, gchar *fallback);
 
+
+void    dnm_clean_event (GdkEventKey *event) {
+  if(!Denemo.prefs.strictshortcuts){
+    guint ret;
+    //g_print("Called %s\n", gdk_keyval_name(event->keyval));
+    gdk_keymap_translate_keyboard_state (NULL, event->hardware_keycode,
+					 GDK_MOD2_MASK/*NumLock forcing numeric keypad to give numbers */, 0/*group 0 */,  &ret, NULL, NULL, NULL);
+    if(ret>='A' && ret <='G')
+      ret += ('a'-'A');
+    event->keyval = ret;
+    
+    //g_print("Changed to %s\n", gdk_keyval_name(event->keyval));
+  }}
+
+
+
 /* Returns the state of the event after removing the modifiers consumed by the
  * system and unwanted modifiers. Use this before doing anything based on the
  * (keyval, state) pair in an event handler.
@@ -79,7 +95,12 @@ load_keymap_file_named (gchar *keymapfile, gchar *fallback);
 guint
 dnm_sanitize_key_state(GdkEventKey *event)
 {
-    guint ret = event->state;
+  guint ret = event->state;
+  if(!Denemo.prefs.strictshortcuts){
+    return ret;
+  }
+
+#if 1
     GdkModifierType consumed;
     /* We want to ignore irrelevant modifiers like ScrollLock */
 
@@ -91,8 +112,10 @@ dnm_sanitize_key_state(GdkEventKey *event)
     ret &= (GDK_CONTROL_MASK | GDK_SHIFT_MASK | GDK_MOD1_MASK
 
  | GDK_MOD2_MASK | GDK_MOD3_MASK | GDK_MOD4_MASK | GDK_MOD5_MASK    /*    these make numlock required to be off for example */);
+#endif
     return ret;
 }
+
 /* Returns the state of the event after removing the modifiers consumed by the
  * system and even more unwanted modifiers. Use this if sanitize is insufficient.
  */
@@ -100,6 +123,7 @@ guint
 dnm_hyper_sanitize_key_state(GdkEventKey *event)
 {
     guint ret = event->state;
+#if 1
     GdkModifierType consumed;
     /* We want to ignore irrelevant modifiers like ScrollLock */
 
@@ -109,6 +133,7 @@ dnm_hyper_sanitize_key_state(GdkEventKey *event)
     ret &= ~consumed;
     /* removing other unwanted modifiers from event->state */
     ret &= (GDK_CONTROL_MASK | GDK_SHIFT_MASK | GDK_MOD1_MASK);
+#endif
     return ret;
 }
 
@@ -122,6 +147,7 @@ guint
 dnm_meta_sanitize_key_state(GdkEventKey *event)
 {
     guint ret = event->state;
+#if 1
     if(ret&GDK_LOCK_MASK) {
       if(!(ret&GDK_SHIFT_MASK))
 	event->keyval += ('a'-'A');
@@ -129,6 +155,7 @@ dnm_meta_sanitize_key_state(GdkEventKey *event)
       
     /* removing everything other than control shift and alt modifiers from event->state */
     ret &= (GDK_CONTROL_MASK | GDK_SHIFT_MASK | GDK_MOD1_MASK);
+#endif
     return ret;
 }
 
@@ -397,11 +424,81 @@ dnm_accelerator_parse (const gchar     *accelerator,
   if (accelerator_mods)
     *accelerator_mods = mods;
 }
+//#include "gdkdisplay-x11.h"
+//gboolean gdk_keymap_get_caps_lock_state (GdkKeymapX11 *keymap_x11) {
+//return keymap_x11->caps_lock_state;
+//}
+// if((gdk_keymap_get_caps_lock_state (gdk_keymap_get_default())!=0) != ((accelerator_mods&GDK_SHIFT_MASK)!=0))
+
 
 gchar*
 dnm_accelerator_name (guint           accelerator_key,
 		      GdkModifierType accelerator_mods)
 {
+ 
+  if(!Denemo.prefs.strictshortcuts){
+    GString *name;
+  
+    name = g_string_new(gdk_keyval_name(accelerator_key));
+    if(name->len>3 && (*name->str=='K') && (*(name->str+1)=='P') && (*(name->str+2)=='_'))
+      g_string_erase(name, 0, 3);//force numeric keypad KP_ names to normal
+
+    //g_print("label %s\nname %s\n", gtk_accelerator_get_label(accelerator_key, 0), 	    gdk_keyval_name(accelerator_key));
+
+
+
+    // g_print("mods were %x\n", accelerator_mods);
+#if 0
+    //do not let caps lock affect shift of backspace etc
+    if( (accelerator_key == GDK_BackSpace) ||
+ (accelerator_key == GDK_Left) ||
+ (accelerator_key == GDK_Right) ||
+ (accelerator_key == GDK_Up) ||
+ (accelerator_key == GDK_Down) ||
+ (accelerator_key == GDK_Page_Up) ||
+ (accelerator_key == GDK_Page_Down) ||
+ (accelerator_key == GDK_Home) ||
+ (accelerator_key == GDK_End) ||
+ (accelerator_key == GDK_Insert) ||
+	(accelerator_key == GDK_Delete) ||
+	(accelerator_key == GDK_KP_Decimal) ||
+	(accelerator_key == GDK_period))
+      accelerator_mods &= ~GDK_LOCK_MASK;
+#else
+    
+ if(!((name->len==1) && (*name->str>='a') && (*name->str<='z')))
+   if(!((name->len==1) && (*name->str>='0') && (*name->str<='9')))
+     accelerator_mods &= ~GDK_LOCK_MASK;
+#endif    
+    // g_print("mods %x\n", accelerator_mods);
+    // if (accelerator_mods&GDK_SHIFT_MASK)
+    
+    //    if((name->len==1) && (*name->str>='A') && (*name->str<='Z'))
+    //      *name->str += ('a'-'A');
+    if(!((name->len==1) && (*name->str>='a') && (*name->str<='z')))
+     if(((accelerator_mods&GDK_LOCK_MASK)!=0) != ((accelerator_mods&GDK_SHIFT_MASK)!=0))
+      g_string_prepend(name, "Shft+");
+
+    if(((accelerator_mods&GDK_LOCK_MASK)!=0) != ((accelerator_mods&GDK_SHIFT_MASK)!=0)) {
+      if((name->len==1) && (*name->str>='a') && (*name->str<='z'))
+	  *name->str -= ('a'-'A');
+    }
+
+    if((accelerator_mods&GDK_CONTROL_MASK))
+      g_string_prepend(name, "Ctrl+");
+
+    if((accelerator_mods&GDK_MOD1_MASK))
+      g_string_prepend(name, "Alt+");
+    if((accelerator_mods&GDK_HYPER_MASK))
+      g_string_prepend(name, "Hypr+");
+    if((accelerator_mods&GDK_MOD4_MASK))
+      g_string_prepend(name, "Mod4+");
+    if((accelerator_mods&GDK_MOD5_MASK))
+      g_string_prepend(name, "Mod5+");
+    return g_string_free(name, FALSE);
+  }
+
+
   static const gchar text_release[] = "<Release>";
   static const gchar text_shift[] = "<Shift>";
   static const gchar text_control[] = "<Control>";
@@ -777,6 +874,21 @@ keymap_size (keymap *the_keymap)
             NULL);
 }
 
+/* returns TRUE if command has at least one binding */
+gboolean
+command_has_binding (guint command_idx)
+{
+    command_row row;
+    GtkTreeIter iter;
+    if( keymap_get_command_row(Denemo.map, &row, command_idx)) {
+      GtkTreeModel *model_bind = GTK_TREE_MODEL(row.bindings);
+      if (!gtk_tree_model_get_iter_first(model_bind, &iter))
+	return FALSE;
+      else
+	return TRUE;
+    }
+    return FALSE;
+}
 /*
  * executes function fun on all bindings attached to a command. The arguments
  * passed to the function are the value of the current binding and the
@@ -827,15 +939,19 @@ lookup_command_for_keybinding (keymap * the_keymap, gint keyval, GdkModifierType
 gint lookup_command_for_keyevent(GdkEventKey * event) {
   keymap *the_keymap = Denemo.map;
   gint command_idx = lookup_command_for_keybinding (the_keymap, event->keyval,
-						    dnm_sanitize_key_state(event));
+						     dnm_sanitize_key_state(event));
+#if 0
   if(!Denemo.prefs.strictshortcuts){
+    //    lookup_command_for_keybinding (the_keymap, event->keyval,
+    //				   dnm_sanitize_key_state(event));
     if(command_idx==-1)
       command_idx = lookup_command_for_keybinding (the_keymap, event->keyval,
 						   dnm_hyper_sanitize_key_state(event)); 
     if(command_idx==-1)
       command_idx = lookup_command_for_keybinding (the_keymap, event->keyval,
 						   dnm_meta_sanitize_key_state(event));
-  }  
+  }
+#endif  
   return command_idx;
 }
 
@@ -1019,12 +1135,16 @@ update_accel_labels(keymap *the_keymap, guint command_idx)
   const gchar *base;
   //FIXME use translate_dnm_to_gtk
   base = lookup_label_from_idx(the_keymap, command_idx);
+#if 0
+  //FIXME here generate a locale dependent name using gtk_accelerator_get_label after back-tracking to find the keyval from the binding (stripping off the prefixes we have added etc). This will be needed for language translation (i.e. _N() should be applied to the gdk_keyval_name() but the label we are writing here should be better with a translated indication of the keybinding (Left becomes Links in German etc).
+  // we have to store an invariant gdk name, so we should look it up here to get the keyval  and from that derive a locale specific name to use on the label. In any case the following transformation is redundant
+
   gchar *c;
   for(c=str->str;*c;c++) {
       if(*c=='<') *c = ' ';
       if(*c=='>') *c = '-';
   }
-
+#endif
   gchar *markup = g_strdup_printf("%s <span style=\"italic\" stretch=\"condensed\" weight=\"bold\" foreground=\"blue\">%s</span>", base, str->str);
 
 
@@ -1157,7 +1277,7 @@ add_named_binding_to_idx (keymap * the_keymap, gchar *kb_name,  guint command_id
   gchar *title = NULL;
   gchar *prompt = NULL;
   if(old_command_idx >= 0) {
-    title = g_strdup_printf("The Command %s Responds to this Shortcut", lookup_name_from_idx(Denemo.map, old_command_idx));
+    title = g_strdup_printf("The Command %s Responds to the Shortcut %s", lookup_name_from_idx(Denemo.map, old_command_idx), kb_name);
     prompt = g_strdup_printf("Lose the shortcut %s for this?", kb_name);
   }
   
@@ -1213,6 +1333,23 @@ add_keybinding_to_idx (keymap * the_keymap, gint keyval,
   return old_command_idx;
 }
 
+/* force keybinding on action of name, returning old command id */
+gint add_keybinding_for_name(gchar *name, gchar *binding) {
+ guint idx = lookup_command_from_name(Denemo.map, name);
+ if(idx!=-1) {
+   return add_named_binding_to_idx(Denemo.map, binding, idx, POS_LAST);
+ }
+ return -1;
+}
+/* force keybinding on action of id, returning old command id */
+gint add_keybinding_for_command(gint idx,  gchar *binding) {
+ 
+ if(idx!=-1) {
+   return add_named_binding_to_idx(Denemo.map, binding, idx, POS_LAST);
+ }
+ return -1;
+}
+
 
 //we have to reproduce this function here since it is static in gtkmenu.c
 static void
@@ -1549,10 +1686,17 @@ static GScannerConfig scanner_config_template = {
 void
 save_keymap_from_dialog (GtkWidget * widget, GtkWidget * filesel)
 {
-  save_xml_keymap ((gchar *)
-		   gtk_file_selection_get_filename (GTK_FILE_SELECTION
-						    (filesel)));
 
+gchar *name = (gchar *)
+		   gtk_file_selection_get_filename (GTK_FILE_SELECTION
+						    (filesel));
+ gchar *extendedname = substitute_extension(name, "commands");
+ save_xml_keymap (extendedname);//no longer save keybindings here
+ 
+ gchar *filename = substitute_extension(extendedname, "shortcuts");
+ save_xml_keybindings(filename);
+ g_free(filename);
+ g_free(extendedname);
 }
 
 /**
@@ -1605,10 +1749,15 @@ save_default_keymap_file (void)
 {
   gchar *localrc = NULL;
   const gchar *keymapdir = locatekeymapdir ();
-  if(keymapdir)
-    localrc = g_build_filename (keymapdir, DEFAULT_KEYMAP, NULL);
-  save_xml_keymap (localrc);
-  g_free(localrc);
+  if(keymapdir) {
+    localrc = g_build_filename (keymapdir, DEFAULT_COMMANDS, NULL);
+    save_xml_keymap (localrc);//no longer saves keybindings
+    g_free(localrc);
+    localrc = g_build_filename (keymapdir, DEFAULT_KEYBINDINGS, NULL);
+    save_xml_keybindings (localrc);
+    g_free(localrc);
+  }
+
 }
 
 /**
