@@ -16,6 +16,12 @@ static 	void show_type(GtkWidget *widget, gchar *message);
 static gchar *
 translate_binding_dnm_to_gtk (const gchar *dnm_binding)
 {
+
+  if(!Denemo.prefs.strictshortcuts) {
+    return g_strdup(dnm_binding);
+  }
+
+
   /* hold is now "modifiers+keyname" or just "keyname" */
   guint len, i;
   gchar **tokens = g_strsplit (dnm_binding, "+", 0);
@@ -49,6 +55,11 @@ translate_binding_dnm_to_gtk (const gchar *dnm_binding)
 static gchar *
 translate_binding_gtk_to_dnm (const gchar *gtk_binding)
 {
+  if(!Denemo.prefs.strictshortcuts) {
+    return g_strdup(gtk_binding);
+  }
+
+
   gchar *res = "", *save, *next, *mod;
   const gchar *cur = gtk_binding;
   while (cur[0] == '<') {
@@ -316,7 +327,6 @@ parseBindings (xmlDocPtr doc, xmlNodePtr cur, keymap * the_keymap)
     {
       //keyval variables
       xmlChar *name, *menupath, *label, *tooltip, *scheme;
-
       if (0 == xmlStrcmp (cur->name, (const xmlChar *) "action"))
 	{
 	  if (cur->xmlChildrenNode == NULL)
@@ -331,6 +341,10 @@ parseBindings (xmlDocPtr doc, xmlNodePtr cur, keymap * the_keymap)
 	      g_print ("Action %s\n", (gchar *) name);
 #endif /*DEBUG*/
 	    }
+	}else if (0 == xmlStrcmp (cur->name, (const xmlChar *) "hidden"))
+	{
+	    hide_action_of_name(name);
+
 	} else if (0 == xmlStrcmp (cur->name, (const xmlChar *) "bind"))
 	{
 	  command_number = lookup_command_from_name (the_keymap, (gchar *) name);
@@ -348,7 +362,9 @@ parseBindings (xmlDocPtr doc, xmlNodePtr cur, keymap * the_keymap)
 		  gchar *gtk_binding = translate_binding_dnm_to_gtk((gchar *) tmp);
 		  //g_print("gtk_binding is %s\n", gtk_binding);
 		  if (gtk_binding) {
-		    dnm_accelerator_parse(gtk_binding, &keyval, &state);
+		    keyval = 0;
+		    if(Denemo.prefs.strictshortcuts)
+		      dnm_accelerator_parse(gtk_binding, &keyval, &state);
 #ifdef DEBUG
 		    g_print ("binding %s, keyval %d, state %d, Command Number %d\n",
 			     gtk_binding, keyval, state, command_number);
@@ -565,6 +581,17 @@ load_xml_keymap (gchar * filename, gboolean interactive)
     }
 
   xmlFreeDoc (doc);
+
+  { //if this is a new-style .commands file, we need to load the keybindings separately
+    gchar *name = g_strdup(filename);
+    gchar *ext = remove_extension(name); 
+    if(ext && !strcmp(ext, "commands")) {
+      gchar *newname = g_strdup_printf("%s%s", name, ".shortcuts");
+      load_xml_keybindings(newname);
+      g_free(newname);
+    }
+    g_free(name);
+  }
   return ret;
 }
 
@@ -609,7 +636,10 @@ load_xml_keybindings (gchar * filename)
       xmlNodePtr cur;
       for (cur = rootElem->xmlChildrenNode; cur != NULL;  cur = cur->next) {
 	if (0 == xmlStrcmp (cur->name, (const xmlChar *) "map")) {
-	  parseBindings (doc, cur->xmlChildrenNode, Denemo.map);
+	  xmlNodePtr ncur;
+	  for(ncur=cur->xmlChildrenNode;ncur != NULL; ncur = ncur->next) {
+	    parseBindings (doc, ncur, Denemo.map);
+	  }
 	  ret = 0;
 	}
       }
@@ -715,8 +745,8 @@ save_xml_keymap (gchar * filename)
       if(after)
 	xmlNewTextChild (child, NULL, (xmlChar *) "after",
 			 (xmlChar *) after);  
-      if(hidden)
-	xmlNewTextChild (child, NULL, (xmlChar *) "hidden", "true");
+      //   if(hidden) store with shortcuts instead
+      //	xmlNewTextChild (child, NULL, (xmlChar *) "hidden", "true");
       if(scheme) 	
 	xmlNewTextChild (child, NULL, (xmlChar *) "scheme",
 			 /* (xmlChar *) scheme*/ (xmlChar*)"");
@@ -737,8 +767,8 @@ save_xml_keymap (gchar * filename)
 	xmlNewTextChild (child, NULL, (xmlChar *) "tooltip",
 			 (xmlChar *) tooltip);
       
-      keymap_foreach_command_binding (the_keymap, i,
-				      (GFunc) write_xml_keybinding_info, child);
+      //  keymap_foreach_command_binding (the_keymap, i,
+      //				      (GFunc) write_xml_keybinding_info, child);
       
     }
 
@@ -748,6 +778,61 @@ save_xml_keymap (gchar * filename)
   return ret;
 }
 
+gint
+save_xml_keybindings (gchar * filename)
+{
+  keymap *the_keymap = Denemo.map;
+  gint i, ret = -1;
+  xmlDocPtr doc;
+  //xmlNsPtr ns;
+  xmlNodePtr parent, child, command;
+
+  doc = xmlNewDoc ((xmlChar *) "1.0");
+  doc->xmlRootNode = parent = xmlNewDocNode (doc, NULL, (xmlChar *) "Denemo",
+					     NULL);
+  child = xmlNewChild (parent, NULL, (xmlChar *) "merge", NULL);
+
+  xmlNewTextChild (child, NULL, (xmlChar *) "title", (xmlChar *) "A Denemo Command Set");
+  xmlNewTextChild (child, NULL, (xmlChar *) "author", (xmlChar *) "AT, JRR, RTS");
+
+  parent = xmlNewChild (child, NULL, (xmlChar *) "map", NULL);
+
+  child = xmlNewChild (parent, NULL, (xmlChar *) "cursors", NULL);
+
+  g_hash_table_foreach(Denemo.map->cursors, (GHFunc)output_pointer_shortcut, child);
+
+
+  for (i = 0; i < keymap_size(the_keymap); i++)
+    {
+      gpointer action = (gpointer)lookup_action_from_idx(the_keymap, i);
+      gchar *scheme = action?g_object_get_data(action, "scheme"):NULL;
+      gboolean deleted = (gboolean) (action?g_object_get_data(action, "deleted"):NULL);
+      gboolean hidden = (gboolean) (action?g_object_get_data(action, "hidden"):NULL);
+      if(deleted && scheme)
+	continue;
+      if(hidden || command_has_binding(i)) {
+	child = xmlNewChild (parent, NULL, (xmlChar *) "row", NULL);
+		
+	gchar *name = (gchar*)lookup_name_from_idx(the_keymap, i);
+#ifdef DEBUG
+	g_print ("%s %s binding(s) \n", name, command_has_binding(i)?"has":"does not have" );
+#endif	
+	xmlNewTextChild (child, NULL, (xmlChar *) "action",
+			 (xmlChar *) name); 
+	if(hidden)
+	  xmlNewTextChild (child, NULL, (xmlChar *) "hidden", "true");
+	
+	keymap_foreach_command_binding (the_keymap, i,
+					(GFunc) write_xml_keybinding_info, child);
+      }
+    }
+
+  xmlSaveFormatFile (filename, doc, 1);
+
+  xmlFreeDoc (doc);
+  return ret;
+}
+
 static 	void show_type(GtkWidget *widget, gchar *message) {
     g_print("%s%s\n",message, widget?g_type_name(G_TYPE_FROM_INSTANCE(widget)):"NULL widget");
   }
