@@ -22,6 +22,8 @@
 
 gint load_xml_keymap(gchar *filename, gboolean interactive);
 gint save_xml_keymap(gchar *filename);
+gint save_xml_keybindings(gchar *filename);
+gint load_xml_keybindings(gchar *filename);
 void set_visibility_for_action(GtkAction *action, gboolean visible);
 gint parse_paths (gchar * filename, DenemoGUI *gui);
 gint save_script_as_xml (gchar * filename, gchar *myname, gchar *myscheme, gchar *mylabel, gchar *mytooltip, gchar *after);
