@@ -102,33 +102,46 @@ scorearea_keypress_event (GtkWidget * widget, GdkEventKey * event)
   DenemoGUI *gui = Denemo.gui;
   keymap *the_keymap = Denemo.map;
   if(divert_key_event && !isModifier(event) && divert_key_id==Denemo.gui->id) {
+    dnm_clean_event (event);
     *divert_key_event = event;
     //g_object_ref(event); FIXME do we need to keep it around?
     gtk_main_quit();
     return TRUE;
   }
-  gint state;
-  state = (lock_mask(event->keyval)^event->state);
-  if(state || ((event->keyval==GDK_Caps_Lock) || (event->keyval==GDK_Num_Lock)))
-    set_cursor_for(state); // MUST LOOK AHEAD to state after keypress HERE CATCH modifiers and set the cursor for them.....
+  // g_print("\n********\nCaps Lock %x?\n\n********\nShifted %x?\n", event->state&GDK_LOCK_MASK,	  event->state&GDK_SHIFT_MASK	  );
+  {
+    gint state;
+    state = (lock_mask(event->keyval)^event->state);
+    if(state || ((event->keyval==GDK_Caps_Lock) || (event->keyval==GDK_Num_Lock)))
+      set_cursor_for(state); // MUST LOOK AHEAD to state after keypress HERE CATCH modifiers and set the cursor for them.....
+  }
+  dnm_clean_event (event);
+
+
+
   /* Look up the keystroke in the keymap and execute the appropriate
    * function */
   gint command_idx = lookup_command_for_keyevent(event);
+  // g_print("Key event keyval %x (gdk calls this \"%s\"), modifiers %x (implies %s %s)\n", event->keyval, gdk_keyval_name(event->keyval), event->state, event->state&GDK_CONTROL_MASK?"Control":"<not ctrl>", event->state&GDK_SHIFT_MASK?"Shift":"<not shift>");
   if (command_idx != -1) {
     const gchar *command_name =
       lookup_name_from_idx (the_keymap, command_idx);
     if (command_name) {
       Denemo.last_keyval = event->keyval;
       Denemo.last_keystate =  dnm_sanitize_key_state(event);
+      call_out_to_guile("(define DenemoKeypressActivatedCommand #t)");
       execute_callback_from_name(the_keymap, command_name);
-      gui = Denemo.gui;
+      call_out_to_guile("(define DenemoKeypressActivatedCommand #f)");
+      gui = Denemo.gui;//may have changed as a result of executing the command
       displayhelper (gui);
       //gtk_widget_draw (gui->scorearea, NULL);//FIXME what is this doing here?   
       return TRUE;
     } else {
+      
       g_warning("No action %i has no name", command_idx);
     }
-  }
+  } else if (!isModifier(event))
+    toggle_to_drawing_area(TRUE);//restore menus, in case the user is lost and needs to look up a keypress
   return TRUE;
 }
 
@@ -273,9 +286,9 @@ octave_shift_key (DenemoGUI * gui, gint amount)
 	  objnode *thenote = nearestnote (gui->si->currentobject->data, gui->si->cursor_y);
 	  if(thenote) {
 	    note copy = *((note *) thenote->data);
-	    delete_chordnote(gui->si);
+	    delete_chordnote(gui);
 	    gui->si->cursor_y = copy.mid_c_offset + amount;
-	    insert_chordnote(gui->si);
+	    insert_chordnote(gui);
 	    changeenshift(gui->si->currentobject->data, gui->si->cursor_y, copy.enshift);
 	    score_status(gui, TRUE);
 	  }
@@ -619,13 +632,13 @@ insert_septuplet (DenemoGUI * gui)
 gboolean
 add_tone_key (DenemoGUI * gui)
 {
- return insert_chordnote (gui->si);
+ return insert_chordnote (gui);
 }
 
 gboolean
 remove_tone_key (DenemoGUI * gui)
 {
-  return delete_chordnote(gui->si);
+  return delete_chordnote(gui);
 }
 
 void
@@ -962,16 +975,7 @@ set_grace (DenemoGUI * gui)
   insertgrace (gui);
 }
 
-void
-toggle_grace (DenemoGUI * gui)
-{
- DenemoObject *curmudelaobj = (DenemoObject *)
-    (gui->si->currentobject ? gui->si->currentobject->data : NULL);
- if(curmudelaobj && (curmudelaobj->type==CHORD)) {
-   ((chord *)curmudelaobj->object)->is_grace ^= GRACED_NOTE;
-   g_print("now %x\n",  ((chord *)curmudelaobj->object)->is_grace);
- }
-}
+
 
 
 void
@@ -992,8 +996,8 @@ change_pitch (DenemoGUI * gui)
     {
       //DenemoObject *theobj =
       //  si->currentobject ? (DenemoObject *) si->currentobject->data : NULL;
-      delete_chordnote(gui->si);
-      insert_chordnote(gui->si); 
+      delete_chordnote(gui);
+      insert_chordnote(gui); 
     }
   // addtone(theobj, si->cursor_y, si->cursoraccs[si->staffletter_y],
   //       si->cursorclef);
@@ -1066,6 +1070,15 @@ newclefsoprano (DenemoGUI * gui)
   object_insert (gui, dnm_newclefobj (DENEMO_SOPRANO_CLEF));
 }
 
+/**
+ * Wrapper function to create new french clef and insert into the score
+ */
+void
+newcleffrench (DenemoGUI * gui)
+{
+  object_insert (gui, dnm_newclefobj (DENEMO_FRENCH_CLEF));
+}
+
 /**
  * Wrapper function to create new 4/4 time sig and insert into the score
  */
@@ -1722,3 +1735,11 @@ setclefsoprano (DenemoGUI * gui)
     dnm_setinitialclef (gui->si, curstaff, DENEMO_SOPRANO_CLEF);
 }
 
+void
+setcleffrench (DenemoGUI * gui)
+{
+  DenemoStaff *curstaff = (DenemoStaff *) gui->si->currentstaff->data;
+  if (curstaff)
+    dnm_setinitialclef (gui->si, curstaff, DENEMO_FRENCH_CLEF);
+}
+
