@@ -765,10 +765,10 @@ gboolean delete_score_directive(gchar *tagname) {
 gchar *\
 what##_directive_get_tag(gchar *tag) {\
   DenemoDirective *directive = get_##what##_directive(tag);\
-  if(directive)\
+  if(directive && directive->tag)\
     return directive->tag->str;\
   else directive = get_##what##_directive(NULL);\
-  if(directive)\
+  if(directive && directive->tag)\
     return directive->tag->str;\
   return NULL;\
 }
@@ -1566,8 +1566,11 @@ standalone_directive_put_graphic(gchar *tag, gchar *value) {
     else
       directive->graphic_name = g_string_new(value);
     return TRUE;
-  } else 
+  } else  {
+    directive->graphic = directive->graphic_name = NULL;
+    directive->width = directive->height = 0;
     return FALSE;
+  }
 }
 
 
