@@ -59,12 +59,21 @@ const gchar *Fluidsynth = "InternalSynth";
 /* just a simple check, if the user has never run denemo before
    better, keep this for whole first session? */
 gboolean first_time_user(void) {
-  gchar *filename = g_build_filename(locatedotdenemo(), "denemorc", NULL);
+  gchar *filename = g_build_filename(locatedotdenemo(), "actions", NULL);
   gboolean ret = !g_file_test (filename, G_FILE_TEST_EXISTS);
   g_free(filename);
   return ret;
 }
 
+gboolean uses_default_commandset(void) {
+  gchar *filename = g_build_filename(locatedotdenemo(), "actions", "Default.commands", NULL);
+  gboolean ret = !g_file_test (filename, G_FILE_TEST_EXISTS);
+  g_free(filename);
+  return ret;
+}
+
+
+
 static const GtkStockItem denemo_stock_items[] = {
   {"denemo-staccato", N_("Staccato"), (GdkModifierType) 0, 0, NULL},
   {"denemo-staccatissimo", N_("Staccatissimo"), (GdkModifierType) 0, 0, NULL},
@@ -495,9 +504,30 @@ main (int argc, char *argv[])
   textdomain (PACKAGE);
 
   register_stock_items ();
-  if(first_time_user())
-    ;
-    // infodialog("Nearly every menu item can be right-clicked, for help, setting keyboard shortcuts and more"); this does not always appear on top of the main window so leave it out for now.
+
+#define choice1  "Default\nUse this until you have read the manual\n"
+#define choice4 "Classic\nOld Denemo pc-keyboard interface."
+#define choice2 "Arranger\nExperienced Users: transcribing music, playing music in, transposing etc"
+#define choice3 "Composer\nExperienced Users: entering and modifying music, working with selections WASD use etc"
+
+  if(uses_default_commandset()) {
+    // infodialog("Nearly every menu item can be right-clicked, for help, setting keyboard shortcuts and more"); this  should always appear on top of the main window, but it is unresponsive to dismissal at first.
+    // get_option returns a pointer into the string passed in
+    gchar *choice = get_option(choice1"\0"choice2"\0"choice3"\0"choice4"\0", strlen(choice1)+1+strlen(choice2)+1+strlen(choice3)+1+strlen(choice4)+1);
+    if(choice==NULL)
+      choice = choice1;
+    if(choice!=choice1) {
+      choice = g_strdup(choice);
+      gchar *c;
+      for(c=choice;*c;c++)
+	if(*c=='\n')
+	  *c='\0';
+      choice =  g_strconcat(choice, ".commands", NULL);
+      choice =  g_build_filename(get_data_dir(), "actions", choice, NULL);
+      //g_print("Choice is %s length %d\n", choice, strlen(choice));
+      Denemo.prefs.shortcut_filename = g_string_new(choice);
+    }
+  }
   //g_print("Calling scm boot guile with %d and %p\n", argc, argv);
   scm_boot_guile (argc, argv, inner_main, NULL);
   
@@ -642,6 +672,7 @@ if (Denemo.prefs.midi_audio_output == Portaudio){
 	g_error_free (error);
       }
   }
+#if 0
   while (dir && (filename = (gchar *) g_dir_read_name (dir)) != NULL)
     {
       if (0 == strcmp ("crashrecovery.denemo", filename))
@@ -693,11 +724,14 @@ if (Denemo.prefs.midi_audio_output == Portaudio){
           gtk_widget_destroy (dialog);
         }
     }
+#endif
 
   if (dir)
     g_dir_close (dir);
 
-
+  if(commandsetfile==NULL)
+    if(Denemo.prefs.shortcut_filename!=NULL && (Denemo.prefs.shortcut_filename->len))
+      commandsetfile = Denemo.prefs.shortcut_filename->str;
 
   if(commandsetfile && (0==load_xml_keymap(commandsetfile, TRUE)))
     ;
