@@ -196,8 +196,16 @@ void center_viewport(void) {
   if(adj->value + amount < adj->upper) {    
       gtk_adjustment_set_value(adj, adj->value + amount);
   } else
-    gtk_adjustment_set_value(adj, adj->upper);
-  return TRUE;
+    gtk_adjustment_set_value(adj, adj->upper-1);
+}
+
+void page_viewport(void) {
+  GtkAdjustment *adj = GTK_ADJUSTMENT(Denemo.gui->hadjustment);
+  gint amount = (Denemo.gui->si->rightmeasurenum-Denemo.gui->si->leftmeasurenum + 1);
+  if(adj->value + amount < adj->upper) {    
+      gtk_adjustment_set_value(adj, adj->value + amount);
+  } else
+    gtk_adjustment_set_value(adj, adj->upper -1);
 }
 
 
@@ -335,7 +343,8 @@ vertical_scroll (GtkAdjustment * adjust, DenemoGUI * gui)
 	    g_list_nth (gui->si->thescore, gui->si->bottom_staff - 1);
 	  setcurrentprimarystaff (gui->si);
 	  setcurrents (gui->si);
-calcmarkboundaries (gui->si);
+	  if(gui->si->markstaffnum)
+	    calcmarkboundaries (gui->si);
 	}
       else if (gui->si->currentstaffnum < gui->si->top_staff)
 	{
@@ -344,7 +353,8 @@ calcmarkboundaries (gui->si);
 	    g_list_nth (gui->si->thescore, gui->si->top_staff - 1);
 	  setcurrentprimarystaff (gui->si);
 	  setcurrents (gui->si);
-calcmarkboundaries (gui->si);
+	  if(gui->si->markstaffnum)
+	    calcmarkboundaries (gui->si);
 	}
       gtk_widget_queue_draw (gui->scorearea);
     }
@@ -393,5 +403,6 @@ void scroll_left(void) {
 }
 
 void scroll_right (void) {
-  h_scroll(Denemo.gui->si->leftmeasurenum+1.0, Denemo.gui);
+  if(Denemo.gui->si->leftmeasurenum < g_list_length (Denemo.gui->si->measurewidths))
+    h_scroll(Denemo.gui->si->leftmeasurenum+1.0, Denemo.gui);
 }
