@@ -25,9 +25,12 @@
 struct callbackdata
 {
   DenemoPrefs *prefs;
+  GtkWidget *shortcut_filename;
   GtkWidget *lilypath;
   GtkWidget *midi_audio_output;
   GtkWidget *immediateplayback;
+  GtkWidget *modal;
+  GtkWidget *cursor_highlight;
   GtkWidget *startmidiin;
   GtkWidget *applytoselection;
   GtkWidget *saveparts;
@@ -36,6 +39,9 @@ struct callbackdata
   GtkWidget *rhythm_palette;
   GtkWidget *object_palette;
   GtkWidget *articulation_palette;
+  GtkWidget *midi_in_controls;
+  GtkWidget *playback_controls;
+
   GtkWidget *console_pane;
   GtkWidget *lyrics_pane;
   GtkWidget *visible_directive_buttons;
@@ -69,6 +75,7 @@ struct callbackdata
 
 #endif
   GtkWidget *display_refresh;
+  GtkWidget *animation_steps;
   GtkWidget *midiplayer;
   GtkWidget *audioplayer;
   GtkWidget *denemopath;
@@ -128,7 +135,7 @@ set_preferences (struct callbackdata *cbdata)
 #define ASSIGNCOMBO2(field) \
   prefs->field = get_midi_audio_pointer(\
     (gchar *) gtk_entry_get_text (GTK_ENTRY (GTK_COMBO (cbdata->field)->entry)));
-
+  ASSIGNTEXT(shortcut_filename)
   ASSIGNTEXT(lilypath)
   ASSIGNTEXT(browser) 
   ASSIGNTEXT(pdfviewer)
@@ -159,6 +166,7 @@ set_preferences (struct callbackdata *cbdata)
     ASSIGNINT(fluidsynth_period_size)
 #endif
   ASSIGNDOUBLE(display_refresh)
+  ASSIGNINT(animation_steps)
   ASSIGNTEXT(temperament)
   ASSIGNBOOLEAN(strictshortcuts)
   ASSIGNBOOLEAN(overlays)
@@ -173,11 +181,15 @@ set_preferences (struct callbackdata *cbdata)
   ASSIGNCOMBO2(midi_audio_output); 
   
   ASSIGNBOOLEAN(immediateplayback)
+  ASSIGNBOOLEAN(modal)
+  ASSIGNBOOLEAN(cursor_highlight)
   ASSIGNBOOLEAN(startmidiin)
   ASSIGNBOOLEAN(applytoselection)
   ASSIGNBOOLEAN(autosave)
   ASSIGNINT(autosave_timeout)
   ASSIGNBOOLEAN(articulation_palette)
+  ASSIGNBOOLEAN(midi_in_controls)
+  ASSIGNBOOLEAN(playback_controls)
   ASSIGNBOOLEAN(console_pane)
   ASSIGNBOOLEAN(lyrics_pane)
   ASSIGNBOOLEAN(visible_directive_buttons)
@@ -331,7 +343,7 @@ preferences_change (GtkAction *action, gpointer param)
    */
   
   NEWPAGE("View");
-  
+  BOOLEANENTRY("Highlight the cursor", cursor_highlight); 
   //Doesnt GList need to be freed
   GList *output_option_list = NULL;
   output_option_list = g_list_append (output_option_list, (gpointer) Portaudio);
@@ -362,11 +374,14 @@ preferences_change (GtkAction *action, gpointer param)
 
   BOOLEANENTRY("Display Note/Rest entry toolbar", notation_palette);
   BOOLEANENTRY("Display articulation palette", articulation_palette);
+  BOOLEANENTRY("Display Controls for Incoming MIDI signals", midi_in_controls);
+  BOOLEANENTRY("Display Controls for Playback", playback_controls);
+
   BOOLEANENTRY("Display console pane", console_pane);
   BOOLEANENTRY("Display lyrics pane", lyrics_pane);
   BOOLEANENTRY("Display Titles. Controls etc", visible_directive_buttons);
 
-  BOOLEANENTRY("Display rhythm pattern toolbar", rhythm_palette);
+  BOOLEANENTRY("Display Music Snippets", rhythm_palette);
   BOOLEANENTRY("Display menu of objects toolbar", object_palette);
   INTENTRY_LIMITS(_("% Zoom"), zoom, 1, 100);
   INTENTRY_LIMITS(_("% of display height per system"), system_height, 1, 100);
@@ -388,7 +403,7 @@ preferences_change (GtkAction *action, gpointer param)
   //  TEXTENTRY("Strict", strictshortcuts)
   BOOLEANENTRY("Apply commands to selection if present", applytoselection);  
   BOOLEANENTRY("Strict Shortcuts", strictshortcuts);
-
+  TEXTENTRY("Shortcut File", shortcut_filename);
   /*
    * External (Helper) Programs 
    */
@@ -408,9 +423,9 @@ preferences_change (GtkAction *action, gpointer param)
    * Misc Menu 
    */
   NEWPAGE("Misc");
-
+  BOOLEANENTRY("Use Denemo modally", modal);   
   DOUBLEENTRY_LIMITS(_("Playback Display Refresh"), display_refresh, 0.001, 0.5, 0.002);
-
+  INTENTRY_LIMITS(_("Page Turn Steps"), animation_steps, 1, 200);
 
   INTENTRY_LIMITS(_("Excerpt Resolution"), resolution, 72, 600);
 
@@ -452,7 +467,8 @@ preferences_change (GtkAction *action, gpointer param)
     gtk_misc_set_alignment (GTK_MISC (label), 1, 0.5);
     gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
   }
-  BOOLEANENTRY("Play back entered notes immediately", immediateplayback);  
+
+  BOOLEANENTRY("Play back entered notes immediately", immediateplayback);   
   BOOLEANENTRY("Auto-start midi in", startmidiin);
 
   COMBOBOX("Midi/Audio output", midi_audio_output, output_option_list, Denemo.prefs.midi_audio_output)
