@@ -21,6 +21,14 @@
 #include "prefops.h"
 #include "playback.h"
 
+#ifdef G_OS_WIN32
+#define PREFS_FILE "denemorcV2"
+#else
+#define PREFS_FILE "denemorc"
+#endif
+
+
+
 static gint
 readxmlprefsFile (gchar * filename);
 
@@ -69,10 +77,13 @@ initprefs ()
   gchar *systemwide = g_build_filename (get_conf_dir (), "denemo.conf", NULL);
   #define ret (&Denemo.prefs)
   gchar * dotdenemo = (gchar*)locatedotdenemo ();
-  gchar *localrc = dotdenemo?g_build_filename (dotdenemo, "denemorc", NULL):NULL;
+  gchar *localrc = dotdenemo?g_build_filename (dotdenemo, PREFS_FILE, NULL):NULL;
 
   /* Reasonable default values */
 
+  ret->mode = INPUTEDIT|INPUTRHYTHM;
+
+
   ret->csoundcommand = g_string_new ("csound -dm6");
 
   ret->csoundorcfile = g_string_new ("");
@@ -113,11 +124,15 @@ initprefs ()
   ret->denemopath = g_string_new (g_get_home_dir());
   ret->lilyversion = g_string_new ("");//meaning use installed LilyPond version
   ret->temperament = g_string_new("Equal");
+  if(ret->shortcut_filename==NULL)
+    ret->shortcut_filename = g_string_new("");
   ret->strictshortcuts = FALSE;
   ret->resolution = 300;
   ret->display_refresh = 0.01;
+  ret->animation_steps = 10;
   ret->overlays = FALSE;
   ret->continuous = TRUE;
+  ret->cursor_highlight = TRUE;
 #ifdef _HAVE_JACK_
   ret->immediateplayback = FALSE;
 #else
@@ -154,6 +169,8 @@ initprefs ()
   ret->maxhistory = 20;
   ret->notation_palette = TRUE;
   ret->articulation_palette = FALSE;
+  ret->midi_in_controls = FALSE;
+  ret->playback_controls = FALSE;
   ret->console_pane = TRUE;
   ret->lyrics_pane = TRUE;
   ret->visible_directive_buttons = TRUE;
@@ -393,7 +410,7 @@ parseConfig (xmlDocPtr doc, xmlNodePtr cur, DenemoPrefs * prefs)
 	  parseDevices(doc, cur, &Denemo.prefs);
 
 	}
-
+      // see below - do not read READXMLENTRY(shortcut_filename)      
 	READXMLENTRY(midiplayer)      
 	READXMLENTRY(audioplayer)        
 	READXMLENTRY(browser)
@@ -444,6 +461,8 @@ parseConfig (xmlDocPtr doc, xmlNodePtr cur, DenemoPrefs * prefs)
       
       READBOOLXMLENTRY(createclones)
       READBOOLXMLENTRY(immediateplayback) 
+      READBOOLXMLENTRY(modal) 
+      READBOOLXMLENTRY(cursor_highlight) 
       READBOOLXMLENTRY(applytoselection) 
       READBOOLXMLENTRY(startmidiin) 
       READINTXMLENTRY(mode) 
@@ -451,6 +470,7 @@ parseConfig (xmlDocPtr doc, xmlNodePtr cur, DenemoPrefs * prefs)
       READBOOLXMLENTRY(strictshortcuts)
       READINTXMLENTRY(resolution)
       READDOUBLEXMLENTRY(display_refresh)
+      READINTXMLENTRY(animation_steps)
       READBOOLXMLENTRY(overlays)
       READBOOLXMLENTRY(continuous)
       READBOOLXMLENTRY(jacktransport)
@@ -458,6 +478,8 @@ parseConfig (xmlDocPtr doc, xmlNodePtr cur, DenemoPrefs * prefs)
       READBOOLXMLENTRY(lilyentrystyle)
       READBOOLXMLENTRY(notation_palette)
       READBOOLXMLENTRY(articulation_palette)
+	READBOOLXMLENTRY(midi_in_controls)
+	READBOOLXMLENTRY(playback_controls)
       READBOOLXMLENTRY(console_pane)
       READBOOLXMLENTRY(lyrics_pane)
       READBOOLXMLENTRY(visible_directive_buttons)
@@ -702,8 +724,7 @@ writeXMLPrefs (DenemoPrefs * prefs)
   static GString *localrc = NULL;
   if (!localrc)
     {
-      localrc = g_string_new (locatedotdenemo ());
-      g_string_append (localrc, "/denemorc");
+      localrc = g_string_new (g_build_filename(locatedotdenemo (), PREFS_FILE, NULL));
     }
 
   doc = xmlNewDoc ((xmlChar *) "1.0");
@@ -733,7 +754,9 @@ writeXMLPrefs (DenemoPrefs * prefs)
     xmlNewChild (child, NULL, (xmlChar *) #field,\
 		 (xmlChar *) prefs->field);}
    
+
   WRITEXMLENTRY(lilypath)
+    // do not store WRITEXMLENTRY(shortcut_filename) it is for internal use. .denemo/Default.xxx is used for the customized shortcuts.
   WRITEXMLENTRY(midiplayer)
   WRITEXMLENTRY(audioplayer)
   WRITEXMLENTRY(csoundcommand)
@@ -788,19 +811,23 @@ writeXMLPrefs (DenemoPrefs * prefs)
   WRITEBOOLXMLENTRY(createclones)
   WRITEBOOLXMLENTRY(lilyentrystyle)
   WRITEBOOLXMLENTRY(immediateplayback)
+  WRITEBOOLXMLENTRY(modal)
+  WRITEBOOLXMLENTRY(cursor_highlight)
   WRITEBOOLXMLENTRY(applytoselection)
   WRITEBOOLXMLENTRY(startmidiin)
   WRITEINTXMLENTRY(mode)
   WRITEBOOLXMLENTRY(strictshortcuts)
   WRITEINTXMLENTRY(resolution)
   WRITEDOUBLEXMLENTRY(display_refresh)
-
+  WRITEINTXMLENTRY(animation_steps)
   WRITEBOOLXMLENTRY(overlays)
   WRITEBOOLXMLENTRY(continuous)
   WRITEBOOLXMLENTRY(jacktransport)
   WRITEBOOLXMLENTRY(jacktransport_start_stopped)
   WRITEINTXMLENTRY(rtcs)
   WRITEBOOLXMLENTRY(notation_palette)
+    WRITEBOOLXMLENTRY(midi_in_controls)
+    WRITEBOOLXMLENTRY(playback_controls)
   WRITEBOOLXMLENTRY(articulation_palette)
   WRITEBOOLXMLENTRY(console_pane)
   WRITEBOOLXMLENTRY(lyrics_pane)
