@@ -10,6 +10,7 @@ register_command(Denemo.map, gtk_action_group_get_action(action_group, "GoToSele
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "PushPosition"), "PushPosition", "Push Position", "Pushes the current cursor position onto a stack", PushPosition);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "PopPosition"), "PopPosition", "Pop Position", "Pops a position from the stack of cursor positions, moving the cursor there", PopPosition);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "PopPushPosition"), "PopPushPosition", "Pop and Push Position", "Pops a position from the stack of cursor positions, pushes the current position, then moves the cursor to the popped position", PopPushPosition);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "ToggleReduceToDrawingArea"), "ToggleReduceToDrawingArea", "Hide/Show Menus", "Hides/Shows menus, panes etc. The ones shown are those checked in the view menu.", ToggleReduceToDrawingArea);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "StaffUp"), "StaffUp", "Staff Up", "Moves the cursor to the staff above, extending selection if any", staffup);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "StaffDown"), "StaffDown", "Staff Down", "Moves the cursor to the staff below, extending selection if any", staffdown);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "MoveToStaffUp"), "MoveToStaffUp", "Move to Staff Up", "Moves the cursor to the staff above without altering selection", movetostaffup);
@@ -18,13 +19,13 @@ register_command(Denemo.map, gtk_action_group_get_action(action_group, "MeasureL
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "MeasureRight"), "MeasureRight", "Measure Right", "Moves the cursor to the first object in the previous measure, extending selection if any", measureright);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "MoveToMeasureLeft"), "MoveToMeasureLeft", "Move to Measure Left", "Moves the cursor to the first object in the next measure leaving selection, if any, unchanged", movetomeasureleft);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "MoveToMeasureRight"), "MoveToMeasureRight", "Move to Measure Right", "Moves the cursor to the first object in the previous measureleaving selection, if any, unchanged", movetomeasureright);
-register_command(Denemo.map, gtk_action_group_get_action(action_group, "A"), "A", "A", "Action for note A (Insert, Edit or Move Cursor, depending on Mode)", go_to_A_key);
-register_command(Denemo.map, gtk_action_group_get_action(action_group, "B"), "B", "B", "Action for note B (Insert, Edit or Move Cursor, depending on Mode)", go_to_B_key);
-register_command(Denemo.map, gtk_action_group_get_action(action_group, "C"), "C", "C", "Action for note C (Insert, Edit or Move Cursor, depending on Mode)", go_to_C_key);
-register_command(Denemo.map, gtk_action_group_get_action(action_group, "D"), "D", "D", "Action for note D (Insert, Edit or Move Cursor, depending on Mode)", go_to_D_key);
-register_command(Denemo.map, gtk_action_group_get_action(action_group, "E"), "E", "E", "Action for note E (Insert, Edit or Move Cursor, depending on Mode)", go_to_E_key);
-register_command(Denemo.map, gtk_action_group_get_action(action_group, "F"), "F", "F", "Action for note F (Insert, Edit or Move Cursor, depending on Mode)", go_to_F_key);
-register_command(Denemo.map, gtk_action_group_get_action(action_group, "G"), "G", "G", "Action for note G (Insert, Edit or Move Cursor, depending on Mode)", go_to_G_key);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "A"), "A", "A", "Append/Edit  A", go_to_A_key);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "B"), "B", "B", "Append/Edit  B", go_to_B_key);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "C"), "C", "C", "Append/Edit  C", go_to_C_key);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "D"), "D", "D", "Append/Edit  D", go_to_D_key);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "E"), "E", "E", "Append/Edit  E", go_to_E_key);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "F"), "F", "F", "Append/Edit  F", go_to_F_key);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "G"), "G", "G", "Append/Edit  G", go_to_G_key);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "OctaveUp"), "OctaveUp", "Octave Up", "Octave Up", octave_up_key);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "OctaveDown"), "OctaveDown", "Octave Down", "Octave Down", octave_down_key);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "WholeNote"), "WholeNote", ""MUSIC_FONT("0")"", "Insert whole-note", insert_chord_0key);
@@ -179,8 +180,9 @@ register_command(Denemo.map, gtk_action_group_get_action(action_group, "SetIniti
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "SetInitialBflatmin"), "SetInitialBflatmin", "Set Bb Minor as Initial Keysig", "No Tooltip yet", setkeysigbflatmin);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "SetInitialEflatmin"), "SetInitialEflatmin", "Set Eb Minor as Initial Keysig", "No Tooltip yet", setkeysigeflatmin);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "SetInitialAflatmin"), "SetInitialAflatmin", "Set Ab Minor as Initial Keysig", "No Tooltip yet", setkeysigaflatmin);
-register_command(Denemo.map, gtk_action_group_get_action(action_group, "SetMark"), "SetMark", "Set Mark", "Sets the start point for a selection,\nthe cursor position is the end point", set_mark);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "SetMark"), "SetMark", "Set Mark", "Sets the start point for a selection,\nthe end point of the selection is unaltered", set_mark);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "UnsetMark"), "UnsetMark", "Unset Mark", "Gets rid of the selection.", unset_mark);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "SetPoint"), "SetPoint", "Set Point", "Extends the selection to the current cursor position", set_point);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "ToggleBeginSlur"), "ToggleBeginSlur", "Begin Slur", "Insert/delete begin slur on this note", toggle_begin_slur);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "ToggleEndSlur"), "ToggleEndSlur", "End Slur", "Insert/delete end slur on this note", toggle_end_slur);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "ToggleStartCrescendo"), "ToggleStartCrescendo", "Start Crescendo", "No Tooltip yet", toggle_start_crescendo);
@@ -209,11 +211,11 @@ register_command(Denemo.map, gtk_action_group_get_action(action_group, "ToggleTh
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "ToggleUpprall"), "ToggleUpprall", "Up Prall (Off/On)", "No Tooltip yet", add_upprall);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "ToggleArpeggio"), "ToggleArpeggio", "Apreggio (Off/On)", "No Tooltip yet", add_arpeggio);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "SetGrace"), "SetGrace", "Set Grace", "No Tooltip yet", set_grace);
-register_command(Denemo.map, gtk_action_group_get_action(action_group, "ToggleGrace"), "ToggleGrace", "Grace Note Off/On", "No Tooltip yet", toggle_grace);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "ToggleGrace"), "ToggleGrace", "Grace Note Off/On", "Makes the note at the cursor a grace note, if it is one, makes it normal", toggle_grace);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "ForceCaution"), "ForceCaution", "Force Cautionary Accidental", "No Tooltip yet", force_cautionary);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "ChangePitch"), "ChangePitch", "Change Pitch", "No Tooltip yet", change_pitch);
-register_command(Denemo.map, gtk_action_group_get_action(action_group, "InsertRhythm"), "InsertRhythm", "Insert Rhythm", "No Tooltip yet", insert_rhythm_pattern);
-register_command(Denemo.map, gtk_action_group_get_action(action_group, "NextRhythm"), "NextRhythm", "Next Rhythm", "Make next rhythm pattern\nthe prevailing rhythm.\nNotes entered will follow this pattern", nextrhythm);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "InsertRhythm"), "InsertRhythm", "Insert Snippet", "No Tooltip yet", insert_rhythm_pattern);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "NextRhythm"), "NextRhythm", "Next Snippet", "Make next snippet\nthe current snippet.\nNotes entered will follow the rhythmic pattern of this snippet", nextrhythm);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "AppendMeasureAllStaffs"), "AppendMeasureAllStaffs", "Append Measure All Staffs", "Appends a blank measure to every staff in this movement", append_measure_score);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "ExecuteScheme"), "ExecuteScheme", "Execute Scheme", "Execute the scheme code from the scripting window", execute_scheme);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "SharpenEnharmonicSet"), "SharpenEnharmonicSet", "Shift Accidentals Sharpwise", "Shifts the set of accidentals one step sharper", set_sharper);
@@ -248,6 +250,7 @@ register_command(Denemo.map, gtk_action_group_get_action(action_group, "Undo"),
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "Redo"), "Redo", "Redo", "Redo", redowrapper);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "Copy"), "Copy", "Copy", "Copy", copywrapper);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "Cut"), "Cut", "Cut", "Cut", cutwrapper);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "Paste"), "Paste", "Paste", "Paste the selected music", pastewrapper);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "PasteClipboard"), "PasteClipboard", "Paste LilyPond notes", "Paste LilyPond notes from the text clipboard", paste_clipboard);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "ScoreProperties"), "ScoreProperties", "Score Properties", "Change some of the properties of the current score. This will start up a dialog window", score_properties_dialog);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "SaveSelection"), "SaveSelection", "Save Selection", "Save the selected music. Not sure if this is working", saveselwrapper);
@@ -321,22 +324,43 @@ register_command(Denemo.map, gtk_action_group_get_action(action_group, "ToggleEd
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "ToggleRest"), "ToggleRest", "Toggle Rest Mode", "Toggle between note entry and rest entry", toggle_rest_mode);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "ToggleRhythm"), "ToggleRhythm", "Toggle Audible Feedback", "Toggle audible feedback on/off", toggle_rhythm_mode);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "ClearOverlay"), "ClearOverlay", "Clear Overlay", "Clear the list of pitches that overlay the notes", clear_overlay);
-register_command(Denemo.map, gtk_action_group_get_action(action_group, "CreateRhythm"), "CreateRhythm", "Create Rhythm", "Copy selection as a rhythm pattern for notes to follow as they are entered", create_rhythm_cb);
-register_command(Denemo.map, gtk_action_group_get_action(action_group, "DeleteRhythm"), "DeleteRhythm", "Delete Rhythm", "Delete the selected rhythm pattern", delete_rhythm_cb);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "CreateRhythm"), "CreateRhythm", "Create Snippet", "Copy selection as music snippet or rhythm pattern for notes to follow as they are entered", create_rhythm_cb);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "DeleteRhythm"), "DeleteRhythm", "Delete Snippet", "Delete the selected music snippet/rhythm pattern", delete_rhythm_cb);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "InsertA"), "InsertA", "Insert A","Inserts note A before note at cursor\nCursor determines which octave\nNote is inserted in the prevailing rhythm",  InsertA);
-register_command(Denemo.map, gtk_action_group_get_action(action_group, "InsertB"), "InsertB", "Insert B","Inserts note B before note at cursor\nCursor determines which octave\nNote is inserted in the prevailing rhythm",  InsertB);
-register_command(Denemo.map, gtk_action_group_get_action(action_group, "InsertC"), "InsertC", "Insert C","Inserts note C before note at cursor\nCursor determines which octave\nNote is inserted in the prevailing rhythm",  InsertC);
-register_command(Denemo.map, gtk_action_group_get_action(action_group, "InsertD"), "InsertD", "Insert D","Inserts note D before note at cursor\nCursor determines which octave\nNote is inserted in the prevailing rhythm",  InsertD);
-register_command(Denemo.map, gtk_action_group_get_action(action_group, "InsertE"), "InsertE", "Insert E","Inserts note E before note at cursor\nCursor determines which octave\nNote is inserted in the prevailing rhythm",  InsertE);
-register_command(Denemo.map, gtk_action_group_get_action(action_group, "InsertF"), "InsertF", "Insert F","Inserts note F before note at cursor\nCursor determines which octave\nNote is inserted in the prevailing rhythm",  InsertF);
-register_command(Denemo.map, gtk_action_group_get_action(action_group, "InsertG"), "InsertG", "Insert G","Inserts note G before note at cursor\nCursor determines which octave\nNote is inserted in the prevailing rhythm",  InsertG);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "AddNoteA"), "AddNoteA", "Insert A After","Inserts note A after note at cursor\nCursor determines which octave\nNote is inserted in the prevailing rhythm",  AddNoteA);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "AddA"), "AddA", "Add A","Adds note A to the chord at cursor\nCursor height determines which octave",  AddA);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "ChangeToA"), "ChangeToA", N_("Change to A"),N_("Changes note at cursor to nearest note A\nRhythm is unchanged"),  ChangeToA);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "MoveToA"), "MoveToA", N_("Move to A"),N_("Moves cursor to nearest note A"),  MoveToA);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "InsertB"), "InsertB", "Insert B","Inserts note B before note at cursor\nCursor determines which octave\nNote is inserted in the prevailing rhythm",  InsertB);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "AddNoteB"), "AddNoteB", "Insert B After","Inserts note B after note at cursor\nCursor determines which octave\nNote is inserted in the prevailing rhythm",  AddNoteB);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "AddB"), "AddB", "Add B","Adds note B to the chord at cursor\nCursor height determines which octave",  AddB);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "ChangeToB"), "ChangeToB", N_("Change to B"),N_("Changes note at cursor to nearest note B\nRhythm is unchanged"),  ChangeToB);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "MoveToB"), "MoveToB", N_("Move to B"),N_("Moves cursor to nearest note B"),  MoveToB);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "InsertC"), "InsertC", "Insert C","Inserts note C before note at cursor\nCursor determines which octave\nNote is inserted in the prevailing rhythm",  InsertC);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "AddNoteC"), "AddNoteC", "Insert C After","Inserts note C after note at cursor\nCursor determines which octave\nNote is inserted in the prevailing rhythm",  AddNoteC);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "AddC"), "AddC", "Add C","Adds note C to the chord at cursor\nCursor height determines which octave",  AddC);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "ChangeToC"), "ChangeToC", N_("Change to C"),N_("Changes note at cursor to nearest note C\nRhythm is unchanged"),  ChangeToC);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "MoveToC"), "MoveToC", N_("Move to C"),N_("Moves cursor to nearest note C"),  MoveToC);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "InsertD"), "InsertD", "Insert D","Inserts note D before note at cursor\nCursor determines which octave\nNote is inserted in the prevailing rhythm",  InsertD);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "AddNoteD"), "AddNoteD", "Insert D After","Inserts note D after note at cursor\nCursor determines which octave\nNote is inserted in the prevailing rhythm",  AddNoteD);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "AddD"), "AddD", "Add D","Adds note D to the chord at cursor\nCursor height determines which octave",  AddD);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "ChangeToD"), "ChangeToD", N_("Change to D"),N_("Changes note at cursor to nearest note D\nRhythm is unchanged"),  ChangeToD);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "MoveToD"), "MoveToD", N_("Move to D"),N_("Moves cursor to nearest note D"),  MoveToD);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "InsertE"), "InsertE", "Insert E","Inserts note E before note at cursor\nCursor determines which octave\nNote is inserted in the prevailing rhythm",  InsertE);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "AddNoteE"), "AddNoteE", "Insert E After","Inserts note E after note at cursor\nCursor determines which octave\nNote is inserted in the prevailing rhythm",  AddNoteE);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "AddE"), "AddE", "Add E","Adds note E to the chord at cursor\nCursor height determines which octave",  AddE);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "ChangeToE"), "ChangeToE", N_("Change to E"),N_("Changes note at cursor to nearest note E\nRhythm is unchanged"),  ChangeToE);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "MoveToE"), "MoveToE", N_("Move to E"),N_("Moves cursor to nearest note E"),  MoveToE);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "InsertF"), "InsertF", "Insert F","Inserts note F before note at cursor\nCursor determines which octave\nNote is inserted in the prevailing rhythm",  InsertF);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "AddNoteF"), "AddNoteF", "Insert F After","Inserts note F after note at cursor\nCursor determines which octave\nNote is inserted in the prevailing rhythm",  AddNoteF);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "AddF"), "AddF", "Add F","Adds note F to the chord at cursor\nCursor height determines which octave",  AddF);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "ChangeToF"), "ChangeToF", N_("Change to F"),N_("Changes note at cursor to nearest note F\nRhythm is unchanged"),  ChangeToF);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "MoveToF"), "MoveToF", N_("Move to F"),N_("Moves cursor to nearest note F"),  MoveToF);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "InsertG"), "InsertG", "Insert G","Inserts note G before note at cursor\nCursor determines which octave\nNote is inserted in the prevailing rhythm",  InsertG);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "AddNoteG"), "AddNoteG", "Insert G After","Inserts note G after note at cursor\nCursor determines which octave\nNote is inserted in the prevailing rhythm",  AddNoteG);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "AddG"), "AddG", "Add G","Adds note G to the chord at cursor\nCursor height determines which octave",  AddG);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "ChangeToG"), "ChangeToG", N_("Change to G"),N_("Changes note at cursor to nearest note G\nRhythm is unchanged"),  ChangeToG);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "MoveToG"), "MoveToG", N_("Move to G"),N_("Moves cursor to nearest note G"),  MoveToG);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "0"), "0", N_(MUSIC_FONT("0")), N_("In insert mode, changes prevailing rhythm to "MUSIC_FONT("0")"\nIn edit mode changes the current note to "MUSIC_FONT("0")"\n or appends a "MUSIC_FONT("0")" if no current note\nIn classic mode inserts a "MUSIC_FONT("0")" at the cursor"), Dur0);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "Change0"), "Change0", N_(MUSIC_FONT("0")), N_("Change the current note to a "MUSIC_FONT("0")), ChangeDur0);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "Insert0"), "Insert0", N_(MUSIC_FONT("0")), N_("Insert a "MUSIC_FONT("0")), InsertDur0);
