@@ -47,6 +47,10 @@ g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "PopPosition")), "scm", (g
 SCM scheme_PopPushPosition(SCM optional);
 install_scm_function ("d-PopPushPosition", scheme_PopPushPosition);
 g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "PopPushPosition")), "scm", (gpointer)1);
+/*ToggleReduceToDrawingArea ToggleReduceToDrawingArea*/
+SCM scheme_ToggleReduceToDrawingArea(SCM optional);
+install_scm_function ("d-ToggleReduceToDrawingArea", scheme_ToggleReduceToDrawingArea);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "ToggleReduceToDrawingArea")), "scm", (gpointer)1);
 /*StaffUp staffup*/
 SCM scheme_StaffUp(SCM optional);
 install_scm_function ("d-StaffUp", scheme_StaffUp);
@@ -731,6 +735,10 @@ g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "SetMark")), "scm", (gpoin
 SCM scheme_UnsetMark(SCM optional);
 install_scm_function ("d-UnsetMark", scheme_UnsetMark);
 g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "UnsetMark")), "scm", (gpointer)1);
+/*SetPoint set_point*/
+SCM scheme_SetPoint(SCM optional);
+install_scm_function ("d-SetPoint", scheme_SetPoint);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "SetPoint")), "scm", (gpointer)1);
 /*ToggleBeginSlur toggle_begin_slur*/
 SCM scheme_ToggleBeginSlur(SCM optional);
 install_scm_function ("d-ToggleBeginSlur", scheme_ToggleBeginSlur);
@@ -999,6 +1007,10 @@ g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "Copy")), "scm", (gpointer
 SCM scheme_Cut(SCM optional);
 install_scm_function ("d-Cut", scheme_Cut);
 g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "Cut")), "scm", (gpointer)1);
+/*Paste pastewrapper*/
+SCM scheme_Paste(SCM optional);
+install_scm_function ("d-Paste", scheme_Paste);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "Paste")), "scm", (gpointer)1);
 /*PasteClipboard paste_clipboard*/
 SCM scheme_PasteClipboard(SCM optional);
 install_scm_function ("d-PasteClipboard", scheme_PasteClipboard);
@@ -1299,48 +1311,111 @@ g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "CreateRhythm")), "scm", (
 SCM scheme_DeleteRhythm(SCM optional);
 install_scm_function ("d-DeleteRhythm", scheme_DeleteRhythm);
 g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "DeleteRhythm")), "scm", (gpointer)1);
-g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "ChangeToA")), "scm", (gpointer)1);
-SCM scheme_ChangeToA(SCM optional);
-install_scm_function ("d-ChangeToA", scheme_ChangeToA);
 g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "InsertA")), "scm", (gpointer)1);
 SCM scheme_InsertA(SCM optional);
 install_scm_function ("d-InsertA", scheme_InsertA);
-g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "ChangeToB")), "scm", (gpointer)1);
-SCM scheme_ChangeToB(SCM optional);
-install_scm_function ("d-ChangeToB", scheme_ChangeToB);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "AddNoteA")), "scm", (gpointer)1);
+SCM scheme_AddNoteA(SCM optional);
+install_scm_function ("d-AddNoteA", scheme_AddNoteA);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "AddA")), "scm", (gpointer)1);
+SCM scheme_AddA(SCM optional);
+install_scm_function ("d-AddA", scheme_AddA);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "ChangeToA")), "scm", (gpointer)1);
+SCM scheme_ChangeToA(SCM optional);
+install_scm_function ("d-ChangeToA", scheme_ChangeToA);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "MoveToA")), "scm", (gpointer)1);
+SCM scheme_MoveToA(SCM optional);
+install_scm_function ("d-MoveToA", scheme_MoveToA);
 g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "InsertB")), "scm", (gpointer)1);
 SCM scheme_InsertB(SCM optional);
 install_scm_function ("d-InsertB", scheme_InsertB);
-g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "ChangeToC")), "scm", (gpointer)1);
-SCM scheme_ChangeToC(SCM optional);
-install_scm_function ("d-ChangeToC", scheme_ChangeToC);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "AddNoteB")), "scm", (gpointer)1);
+SCM scheme_AddNoteB(SCM optional);
+install_scm_function ("d-AddNoteB", scheme_AddNoteB);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "AddB")), "scm", (gpointer)1);
+SCM scheme_AddB(SCM optional);
+install_scm_function ("d-AddB", scheme_AddB);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "ChangeToB")), "scm", (gpointer)1);
+SCM scheme_ChangeToB(SCM optional);
+install_scm_function ("d-ChangeToB", scheme_ChangeToB);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "MoveToB")), "scm", (gpointer)1);
+SCM scheme_MoveToB(SCM optional);
+install_scm_function ("d-MoveToB", scheme_MoveToB);
 g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "InsertC")), "scm", (gpointer)1);
 SCM scheme_InsertC(SCM optional);
 install_scm_function ("d-InsertC", scheme_InsertC);
-g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "ChangeToD")), "scm", (gpointer)1);
-SCM scheme_ChangeToD(SCM optional);
-install_scm_function ("d-ChangeToD", scheme_ChangeToD);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "AddNoteC")), "scm", (gpointer)1);
+SCM scheme_AddNoteC(SCM optional);
+install_scm_function ("d-AddNoteC", scheme_AddNoteC);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "AddC")), "scm", (gpointer)1);
+SCM scheme_AddC(SCM optional);
+install_scm_function ("d-AddC", scheme_AddC);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "ChangeToC")), "scm", (gpointer)1);
+SCM scheme_ChangeToC(SCM optional);
+install_scm_function ("d-ChangeToC", scheme_ChangeToC);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "MoveToC")), "scm", (gpointer)1);
+SCM scheme_MoveToC(SCM optional);
+install_scm_function ("d-MoveToC", scheme_MoveToC);
 g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "InsertD")), "scm", (gpointer)1);
 SCM scheme_InsertD(SCM optional);
 install_scm_function ("d-InsertD", scheme_InsertD);
-g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "ChangeToE")), "scm", (gpointer)1);
-SCM scheme_ChangeToE(SCM optional);
-install_scm_function ("d-ChangeToE", scheme_ChangeToE);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "AddNoteD")), "scm", (gpointer)1);
+SCM scheme_AddNoteD(SCM optional);
+install_scm_function ("d-AddNoteD", scheme_AddNoteD);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "AddD")), "scm", (gpointer)1);
+SCM scheme_AddD(SCM optional);
+install_scm_function ("d-AddD", scheme_AddD);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "ChangeToD")), "scm", (gpointer)1);
+SCM scheme_ChangeToD(SCM optional);
+install_scm_function ("d-ChangeToD", scheme_ChangeToD);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "MoveToD")), "scm", (gpointer)1);
+SCM scheme_MoveToD(SCM optional);
+install_scm_function ("d-MoveToD", scheme_MoveToD);
 g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "InsertE")), "scm", (gpointer)1);
 SCM scheme_InsertE(SCM optional);
 install_scm_function ("d-InsertE", scheme_InsertE);
-g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "ChangeToF")), "scm", (gpointer)1);
-SCM scheme_ChangeToF(SCM optional);
-install_scm_function ("d-ChangeToF", scheme_ChangeToF);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "AddNoteE")), "scm", (gpointer)1);
+SCM scheme_AddNoteE(SCM optional);
+install_scm_function ("d-AddNoteE", scheme_AddNoteE);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "AddE")), "scm", (gpointer)1);
+SCM scheme_AddE(SCM optional);
+install_scm_function ("d-AddE", scheme_AddE);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "ChangeToE")), "scm", (gpointer)1);
+SCM scheme_ChangeToE(SCM optional);
+install_scm_function ("d-ChangeToE", scheme_ChangeToE);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "MoveToE")), "scm", (gpointer)1);
+SCM scheme_MoveToE(SCM optional);
+install_scm_function ("d-MoveToE", scheme_MoveToE);
 g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "InsertF")), "scm", (gpointer)1);
 SCM scheme_InsertF(SCM optional);
 install_scm_function ("d-InsertF", scheme_InsertF);
-g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "ChangeToG")), "scm", (gpointer)1);
-SCM scheme_ChangeToG(SCM optional);
-install_scm_function ("d-ChangeToG", scheme_ChangeToG);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "AddNoteF")), "scm", (gpointer)1);
+SCM scheme_AddNoteF(SCM optional);
+install_scm_function ("d-AddNoteF", scheme_AddNoteF);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "AddF")), "scm", (gpointer)1);
+SCM scheme_AddF(SCM optional);
+install_scm_function ("d-AddF", scheme_AddF);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "ChangeToF")), "scm", (gpointer)1);
+SCM scheme_ChangeToF(SCM optional);
+install_scm_function ("d-ChangeToF", scheme_ChangeToF);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "MoveToF")), "scm", (gpointer)1);
+SCM scheme_MoveToF(SCM optional);
+install_scm_function ("d-MoveToF", scheme_MoveToF);
 g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "InsertG")), "scm", (gpointer)1);
 SCM scheme_InsertG(SCM optional);
 install_scm_function ("d-InsertG", scheme_InsertG);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "AddNoteG")), "scm", (gpointer)1);
+SCM scheme_AddNoteG(SCM optional);
+install_scm_function ("d-AddNoteG", scheme_AddNoteG);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "AddG")), "scm", (gpointer)1);
+SCM scheme_AddG(SCM optional);
+install_scm_function ("d-AddG", scheme_AddG);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "ChangeToG")), "scm", (gpointer)1);
+SCM scheme_ChangeToG(SCM optional);
+install_scm_function ("d-ChangeToG", scheme_ChangeToG);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "MoveToG")), "scm", (gpointer)1);
+SCM scheme_MoveToG(SCM optional);
+install_scm_function ("d-MoveToG", scheme_MoveToG);
 /*0 */
 g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "0")), "scm", (gpointer)1);
 SCM scheme_0(SCM optional);
