@@ -156,7 +156,9 @@ goto_movement_staff_obj (DenemoGUI * gui, gint movementnum, gint staffnum, gint
     gui->si->currentobject = gui->si->currentobject->next;
     gui->si->cursor_x++;
   }
-  if(objnum)
+  // g_print("objnum %d\n",objnum);
+  gui->si->cursor_x+=objnum;
+  if(!gui->si->currentobject)
     return FALSE;
   write_status(gui);
 #if 0
@@ -184,6 +186,11 @@ void PopPosition (GtkAction * action, DenemoScriptParam *param) {
     return;
   }
   param->status = goto_movement_staff_obj(Denemo.gui, pos->movement, pos->staff, pos->measure, pos->object);
+  if(param->status)
+    {
+      Denemo.gui->si->cursor_appending = pos->appending;
+      Denemo.gui->si->cursoroffend = pos->offend;
+    }
   g_free(pos);
 }
 
@@ -199,6 +206,11 @@ void PopPushPosition (GtkAction * action, DenemoScriptParam *param) {
   if(pos) {
     push_position();
     param->status = goto_movement_staff_obj(Denemo.gui, pos->movement, pos->staff, pos->measure, pos->object);
+  if(param->status)
+    {
+      Denemo.gui->si->cursor_appending = pos->appending;
+      Denemo.gui->si->cursoroffend = pos->offend;
+    }
   } else
     param->status = FALSE;
 }
