@@ -69,6 +69,15 @@ gboolean pop_clipboard(void) {
   return TRUE;
 }
 
+/* returns the top clipboard popped off the stack.
+   The caller must free the clipboard with 
+   when done */
+GList *pop_off_clipboard(void) {
+  GList *thecopy = NULL;
+  thecopy = clipboards->data;
+  clipboards = g_list_remove(clipboards, thecopy);
+  return thecopy;
+}
 
 /**
  *  sets current object to the given cursor position
@@ -92,7 +101,7 @@ setcurrentobject (DenemoScore * si, gint cursorpos)
  *  return - none
  */
 void
-clearbuffer ()
+clearbuffer (void)
 {
   g_list_foreach (copybuffer, freeobjlist, NULL);
   g_list_free (copybuffer);
@@ -101,7 +110,26 @@ clearbuffer ()
   measurebreaksinbuffer = 0;
 }
 
+void
+free_clipboard(GList *clipboard) {
+  if(clipboard) {
+    push_clipboard();
+    copybuffer = clipboard;
+    clearbuffer();
+    pop_clipboard();
+  }
+}
 
+void
+insert_clipboard(GList *clipboard) {
+  if(clipboard) {
+    push_clipboard();
+    copybuffer = clipboard;
+    call_out_to_guile("(d-Paste)");
+    copybuffer = NULL;
+    pop_clipboard();
+  }
+}
 /**
  *  saveselection 
  *  Saves the current selection to a given file
@@ -183,13 +211,15 @@ copytobuffer (DenemoScore * si)
 	  
 	  if (j < si->lastmeasuremarked || k < si->lastobjmarked)
 	    {
-	      g_debug ("Insert measurebreak obj in copybuffer");
-	      /* That is, there's another measure, the cursor is in appending
-	         position, or the selection spans multiple staffs, in which 
-	         case another measure boundary should be added.  */
-	      theobjs = g_list_append (theobjs, newmeasurebreakobject ());
-	      if (i == si->firststaffmarked)
-		measurebreaksinbuffer++;
+	      if(!((j==si->lastmeasuremarked))) {
+		g_debug ("Insert measurebreak obj in copybuffer");
+		/* ???outdated comment??? That is, there's another measure, the cursor is in appending
+		   position, or the selection spans multiple staffs, in which 
+		   case another measure boundary should be added.  */
+		theobjs = g_list_append (theobjs, newmeasurebreakobject ());
+		if (i == si->firststaffmarked)
+		  measurebreaksinbuffer++;
+	      }
 	    }
 	  k = 0;		/* Set it for next run through object loop */
 	  
@@ -199,7 +229,8 @@ copytobuffer (DenemoScore * si)
 	  theobjs = g_list_append (theobjs, newstaffbreakobject ());
 	  g_debug ("Inserting Staffbreak object in copybuffer");
 	}
-      copybuffer = g_list_append (copybuffer, theobjs);
+      if(theobjs)
+	copybuffer = g_list_append (copybuffer, theobjs);
     }				/* End staff loop */
 }
 
@@ -210,8 +241,8 @@ copytobuffer (DenemoScore * si)
  *
  *  @param si pointer to score information structure
  */
-void
-cuttobuffer (DenemoScore * si)
+static void
+cuttobuffer (DenemoScore * si, gboolean copyfirst)
 {
   staffnode *curstaff;
   measurenode *curmeasure;
@@ -220,16 +251,23 @@ cuttobuffer (DenemoScore * si)
     max;
   if (!si->markstaffnum)
     return;
-  copytobuffer (si);
+  if(copyfirst)
+    copytobuffer (si);
   gint staffs_removed_measures = 0;// a count of removed measures in the case where multiple staffs are involved
-  if (staffsinbuffer == 1)
+  gint lmeasurebreaksinbuffer = si->lastmeasuremarked - si->firstmeasuremarked;
+  gint lstaffsinbuffer = si->laststaffmarked - si->firststaffmarked + 1;
+  if(copyfirst) {
+    g_assert( lmeasurebreaksinbuffer == measurebreaksinbuffer);
+    g_assert(lstaffsinbuffer == staffsinbuffer);
+  }
+  if (lstaffsinbuffer == 1)
     {
       /* Just a single staff is a special case, again.  */
       jcounter = si->firstmeasuremarked; //currently clearing stuff from the firstmeasuremarked
       curmeasure = g_list_nth (firstmeasurenode (si->currentstaff), jcounter - 1);
 
       /* Clear the relevant part of the first measure selected */
-      if (measurebreaksinbuffer)
+      if (lmeasurebreaksinbuffer)
 	max = G_MAXINT;
       else
 	max = si->lastobjmarked;
@@ -249,11 +287,11 @@ cuttobuffer (DenemoScore * si)
 	{
 	  /* That is, the score has only this one staff
 	   remove the (whole) measures between the first and last - which may be partial.*/
-	  if (measurebreaksinbuffer - 1 > 0)
+	  if (lmeasurebreaksinbuffer - 1 > 0)
 	    {
 	      curmeasure =
-		removemeasures (si, jcounter - 1, measurebreaksinbuffer - 1, TRUE);
-	      jcounter += measurebreaksinbuffer - 1;// increased by the number of measures *between* first and last marked
+		removemeasures (si, jcounter - 1, lmeasurebreaksinbuffer - 1, TRUE);
+	      jcounter += lmeasurebreaksinbuffer - 1;// increased by the number of measures *between* first and last marked
 	    }
 	}
       else
@@ -292,27 +330,26 @@ cuttobuffer (DenemoScore * si)
     } // end of single staff
   else
     {				/* Multiple staff selection */
-      if (staffsinbuffer == (gint) (g_list_length (si->thescore)))
+      if (lstaffsinbuffer == (gint) (g_list_length (si->thescore)))
 	{
 	  /* Every staff was part of the selection */
-	  if (measurebreaksinbuffer > 0)
+	  if (lmeasurebreaksinbuffer > 0)
 	    {
 	      
 	      removemeasures (si, si->firstmeasuremarked - 1,
-			    measurebreaksinbuffer, TRUE);
-	      staffs_removed_measures = measurebreaksinbuffer;
-	    }
-	  for (curstaff = si->thescore; curstaff; curstaff = curstaff->next)
-	    {
-	      if(measurebreaksinbuffer==0)
-		{
-		  curmeasure = g_list_nth (firstmeasurenode (curstaff),  si->firstmeasuremarked-1);
-		  freeobjlist (curmeasure->data, NULL);
-		  curmeasure->data = NULL;
-		}
-	      showwhichaccidentalswholestaff ((DenemoStaff *) curstaff->data);
-	      beamsandstemdirswholestaff ((DenemoStaff *) curstaff->data);
+			    lmeasurebreaksinbuffer+1, TRUE);
+	      staffs_removed_measures = lmeasurebreaksinbuffer;
 	    }
+	  else
+	    for (curstaff = si->thescore; curstaff; curstaff = curstaff->next)
+	      {
+		curmeasure = g_list_nth (firstmeasurenode (curstaff),  si->firstmeasuremarked-1);
+		freeobjlist (curmeasure->data, NULL);
+		curmeasure->data = NULL;
+		
+		showwhichaccidentalswholestaff ((DenemoStaff *) curstaff->data);
+		beamsandstemdirswholestaff ((DenemoStaff *) curstaff->data);
+	      }
 	}
       else
 	{
@@ -401,10 +438,20 @@ DenemoObjType get_clip_obj_type(gint m, gint n) {
   return ((DenemoObject*)(curbufferobj->data))->type;
 }
 
+gint get_clip_objs(gint m) {
+  if(copybuffer==NULL)
+    return -1;
+  GList *stafflist = g_list_nth(copybuffer, m);
+  if(stafflist==NULL)
+    return -1;
+  return g_list_length(stafflist->data);
+}
+
 // insert the nth object from the copybuffer into music at the cursor position
 // return TRUE if inserted
 gboolean insert_clip_obj(gint m, gint n) {
   DenemoScore *si = Denemo.gui->si;
+  staffnode *curstaff = si->currentstaff;
   if(copybuffer==NULL)
     return FALSE;
   GList *stafflist = g_list_nth(copybuffer, m);
@@ -428,6 +475,8 @@ gboolean insert_clip_obj(gint m, gint n) {
   else
     si->currentobject = g_list_nth ((objnode *) si->currentmeasure->data,
 				    si->cursor_x);
+  beamsandstemdirswholestaff ((DenemoStaff *) curstaff->data);
+  find_xes_in_all_measures (si);
   return TRUE;
 }
 /**
@@ -596,6 +645,77 @@ DenemoObject *get_point_object(void){
   return lastobj? ((DenemoObject *)lastobj->data):NULL;
 }
 
+/**
+ * mark_boundaries_helper
+ * Helper function which marks the boundaries of the 
+ * mark
+ *
+ * Inputs 
+ * @param si pointer to the DenemoScore structure
+ * @param mark_staff  
+ * @param mark_measure -
+ * @param mark_object -
+ * @param point_staff -
+ * @param point_measure -
+ * @param point_object -
+ * @param type -
+ */
+static void
+mark_boundaries_helper (DenemoScore * si, gint mark_staff,
+			gint mark_measure, gint mark_object, gint point_staff,
+			gint point_measure, gint point_object,
+			enum drag_selection_type type)
+{
+  if (mark_staff)
+    {
+      si->firststaffmarked = MIN (mark_staff, point_staff);
+      si->laststaffmarked = MAX (mark_staff, point_staff);
+
+      switch (type)
+	{
+	case NO_DRAG:
+	  /* error, really.  */
+	  break;
+	case NORMAL_SELECT:
+	case WHOLE_MEASURES:
+	  /* I was thinking of handling these with a fallthrough, but
+	     the commonality in setting si->firstmeasuremarked and
+	     si->lastmeasuremarked caused it not to work out cleanly.  */
+	  si->firstmeasuremarked = MIN (mark_measure, point_measure);
+	  si->lastmeasuremarked = MAX (mark_measure, point_measure);
+	  if (type == NORMAL_SELECT
+	        && si->firststaffmarked == si->laststaffmarked )
+	    {
+	      if (mark_measure < point_measure)
+		{
+		  si->firstobjmarked = mark_object;
+		  si->lastobjmarked = point_object;
+		}
+	      else if (mark_measure > point_measure)
+		{
+		  si->firstobjmarked = point_object;
+		  si->lastobjmarked = mark_object;
+		}
+	      else
+		{		/* Same measure */
+		  si->firstobjmarked = MIN (mark_object, point_object);
+		  si->lastobjmarked = MAX (mark_object, point_object);
+		}
+	    }
+	  else
+	    {
+	      si->firstobjmarked = 0;
+	      si->lastobjmarked = G_MAXINT;
+	    }
+	  break;
+	case WHOLE_STAFFS:
+	  si->firstmeasuremarked = 1;
+	  si->lastmeasuremarked = g_list_length (si->measurewidths);
+	  si->firstobjmarked = 0;
+	  si->lastobjmarked = G_MAXINT;
+	}
+    }
+}
 
 
 /**
@@ -614,6 +734,26 @@ set_mark (DenemoGUI * gui)
   calcmarkboundaries (si);
 }
 
+/**
+ *  set_point
+ *  Sets the current cursor position as the end of the selection
+ *
+ *  @param gui pointer to the DenemoGUI structure
+ */
+void
+set_point (DenemoGUI * gui)
+{
+  DenemoScore *si = gui->si;
+  if(si->markstaffnum) {
+    mark_boundaries_helper (si, si->markstaffnum, si->markmeasurenum,
+			  si->markcursor_x, si->currentstaffnum,
+			  si->currentmeasurenum, si->cursor_x, NORMAL_SELECT);
+ 
+  }
+}
+
+
+
 /**
  * unset_mark
  * Remove the current mark
@@ -761,6 +901,8 @@ void push_position(void) {
   pos->staff =  si->currentstaffnum;
   pos->measure = si->currentmeasurenum;
   pos->object =  si->currentobject?si->cursor_x+1:0;
+  pos->appending = si->cursor_appending;
+  pos->offend = si->cursoroffend;
   if(pos->movement)
      positions = g_slist_prepend(positions, pos);
   else
@@ -794,11 +936,17 @@ void
 cutwrapper (GtkAction *action, DenemoScriptParam *param)
 {
   DenemoGUI *gui = Denemo.gui;
-  cuttobuffer (gui->si);
+  cuttobuffer (gui->si, TRUE);
   //check that measurewidths is long enough after cutting empty measures
   displayhelper (gui);
 }
 
+void
+delete_selection(void) {
+  DenemoGUI *gui = Denemo.gui;
+  cuttobuffer (gui->si, FALSE);
+  displayhelper (gui);
+}
 /**
  * pastewrapper
  * Wrapper function for the paste command
@@ -809,20 +957,7 @@ cutwrapper (GtkAction *action, DenemoScriptParam *param)
 void
 pastewrapper (GtkAction *action, DenemoScriptParam *param)
 {  
-  DenemoGUI *gui = Denemo.gui;
-  gboolean pasted = pastefrombuffer ();
-  if(pasted) {
-  score_status(gui, TRUE);
-  displayhelper (gui);
-  } else {
-    if(!action && param)
-      param->status = FALSE;
-    else
-      if(copybuffer)
-	warningdialog("Cannot paste multiple measures into middle of a measure");
-      else
-	warningdialog("Nothing to paste");
-  }
+  call_out_to_guile("(DenemoPaste)");
 }
 
 
@@ -840,77 +975,6 @@ saveselwrapper (GtkAction *action, DenemoScriptParam *param)
   saveselection (gui->si);
 }
 
-/**
- * mark_boundaries_helper
- * Helper function which marks the boundaries of the 
- * mark
- *
- * Inputs 
- * @param si pointer to the DenemoScore structure
- * @param mark_staff  
- * @param mark_measure -
- * @param mark_object -
- * @param point_staff -
- * @param point_measure -
- * @param point_object -
- * @param type -
- */
-void
-mark_boundaries_helper (DenemoScore * si, gint mark_staff,
-			gint mark_measure, gint mark_object, gint point_staff,
-			gint point_measure, gint point_object,
-			enum drag_selection_type type)
-{
-  if (mark_staff)
-    {
-      si->firststaffmarked = MIN (mark_staff, point_staff);
-      si->laststaffmarked = MAX (mark_staff, point_staff);
-
-      switch (type)
-	{
-	case NO_DRAG:
-	  /* error, really.  */
-	  break;
-	case NORMAL_SELECT:
-	case WHOLE_MEASURES:
-	  /* I was thinking of handling these with a fallthrough, but
-	     the commonality in setting si->firstmeasuremarked and
-	     si->lastmeasuremarked caused it not to work out cleanly.  */
-	  si->firstmeasuremarked = MIN (mark_measure, point_measure);
-	  si->lastmeasuremarked = MAX (mark_measure, point_measure);
-	  if (type == NORMAL_SELECT
-	        && si->firststaffmarked == si->laststaffmarked )
-	    {
-	      if (mark_measure < point_measure)
-		{
-		  si->firstobjmarked = mark_object;
-		  si->lastobjmarked = point_object;
-		}
-	      else if (mark_measure > point_measure)
-		{
-		  si->firstobjmarked = point_object;
-		  si->lastobjmarked = mark_object;
-		}
-	      else
-		{		/* Same measure */
-		  si->firstobjmarked = MIN (mark_object, point_object);
-		  si->lastobjmarked = MAX (mark_object, point_object);
-		}
-	    }
-	  else
-	    {
-	      si->firstobjmarked = 0;
-	      si->lastobjmarked = G_MAXINT;
-	    }
-	  break;
-	case WHOLE_STAFFS:
-	  si->firstmeasuremarked = 1;
-	  si->lastmeasuremarked = g_list_length (si->measurewidths);
-	  si->firstobjmarked = 0;
-	  si->lastobjmarked = G_MAXINT;
-	}
-    }
-}
 
 /**
  * calcmarkboundaries
