@@ -268,7 +268,7 @@ newstaff (DenemoGUI * gui, enum newstaffcallbackaction action,
       thestaffstruct->space_above = 0;
       thestaffstruct->space_below = 0;
       thestaffstruct->nummeasures = 1;
-
+      thestaffstruct->midi_channel = 0;
 #if 0
       si->measurewidths = g_list_append (si->measurewidths,
 					 GINT_TO_POINTER (si->measurewidth));
@@ -281,6 +281,7 @@ newstaff (DenemoGUI * gui, enum newstaffcallbackaction action,
       thestaffstruct->nummeasures = g_list_length (firstmeasurenode (si->thescore));
       copy_staff_bits ((DenemoStaff *) si->currentstaff->data,
 		       thestaffstruct);
+      thestaffstruct->midi_channel = (numstaffs<9?numstaffs:numstaffs+1)&0xF;
     }
 
   if (action == NEWVOICE)
@@ -506,7 +507,8 @@ deletestaff (DenemoGUI * gui, gboolean interactive)
       setcurrentprimarystaff (si);
     }
   setcurrents (si);
-calcmarkboundaries (si);
+  if(si->markstaffnum)
+    calcmarkboundaries (si);
   if(gui->si->currentstaffnum < gui->si->top_staff)
     gui->si->top_staff = gui->si->currentstaffnum; 
   update_vscrollbar (gui);
@@ -619,7 +621,7 @@ newstaffinitial (GtkAction *action, gpointer param)
 {
   DenemoGUI *gui = Denemo.gui;
   while(gui->si->currentstaff && gui->si->currentstaff->prev)
-    staffup(param);
+    movetostaffup(param);
   newstaffbefore (action, NULL);
 }
 
@@ -644,7 +646,7 @@ newstaffbefore (GtkAction *action, gpointer param)
   set_bottom_staff (gui);
   move_viewport_down (gui);
 
-  staffup (param);
+  movetostaffup (param);
   displayhelper (gui);
 
 }
@@ -661,11 +663,11 @@ dnm_newstaffafter (GtkAction *action, gpointer param)
   DenemoGUI *gui = Denemo.gui;
   if(!confirm_insertstaff_custom_scoreblock(gui))
     return;
-  tohome(NULL, NULL);
+  movetostart(NULL, NULL);
   newstaff (gui, AFTER, DENEMO_NONE);
   set_bottom_staff (gui);
   update_vscrollbar (gui);
-  staffdown (param);
+  movetostaffdown (param);
   displayhelper (gui);
 }
 
@@ -680,7 +682,7 @@ newstafflast (GtkAction *action, gpointer param)
 {
   DenemoGUI *gui = Denemo.gui;
   while(gui->si->currentstaff && gui->si->currentstaff->next)
-    staffdown(param);
+    movetostaffdown(param);
   dnm_newstaffafter(action, param);
 }
 
@@ -698,7 +700,8 @@ dnm_newstaffvoice (GtkAction *action, gpointer param)
   set_bottom_staff (gui);
   update_vscrollbar (gui);
   setcurrents(gui->si);
-calcmarkboundaries (gui->si);
+  if(gui->si->markstaffnum)
+    calcmarkboundaries (gui->si);
   displayhelper (gui);
 }
 
