@@ -10,8 +10,8 @@
 
 #include <denemo/denemo.h>
 
-mudelaobject *newtupopen (gint numerator, gint denominator);
+DenemoObject *newtupopen (gint numerator, gint denominator);
 
-mudelaobject *newtupclose ();
+DenemoObject *newtupclose ();
 
-void tupletchangedialog (mudelaobject * newobj, GtkWidget * scorearea);
+void tupletchangedialog (DenemoObject * newobj, GtkWidget * scorearea);
