@@ -96,9 +96,10 @@ infodialog (gchar * msg)
   dialog = gtk_message_dialog_new (GTK_WINDOW (Denemo.window),
 				   GTK_DIALOG_DESTROY_WITH_PARENT,
 				   GTK_MESSAGE_INFO, GTK_BUTTONS_CLOSE, "%s", msg);
- g_signal_connect_swapped (dialog, "response",
-                           G_CALLBACK (gtk_widget_destroy),
-                           dialog);
+  g_signal_connect_swapped (dialog, "response",
+			    G_CALLBACK (gtk_widget_destroy),
+			    dialog);
+  gtk_window_set_keep_above(dialog, TRUE);
   gtk_widget_show_all(dialog);
 }
 
@@ -441,6 +442,9 @@ calculateheight (gint mid_c_offset, gint dclef)
     case DENEMO_SOPRANO_CLEF:
       return LINE_SPACE - HALF_LINE_SPACE * (mid_c_offset - 6);
       break;
+    case DENEMO_FRENCH_CLEF:
+      return 6 * LINE_SPACE - HALF_LINE_SPACE * (mid_c_offset);
+      break;
     }
 
   return (0);
@@ -970,8 +974,11 @@ void write_status(DenemoGUI *gui) {
 
   status = "Movement";
   gint index = g_list_index(gui->movements, gui->si);
-  status = g_strdup_printf("%s %d: %s: %d min %.2f sec %.2f %.2f", status, index+1, selection, minutes, seconds, early, late);
-
+  if((gui->si->smfsync == gui->si->changecount) && (GTK_WIDGET_VISIBLE (Denemo.playback_control)))
+    status = g_strdup_printf("%s %d: %s: %d min %.2f sec %.2f %.2f", status, index+1, selection, minutes, seconds, early, late);
+  else
+    status = g_strdup_printf("%s %d: %s: Staff %d Measure %d Object %d %s", status, index+1, selection, gui->si->currentstaffnum, gui->si->currentmeasurenum, gui->si->cursor_x, gui->si->cursor_appending?"Appending":"Not Appending"/*not understood this one... , gui->si->cursoroffend?"Off End":"Not Off End" */);
+  
   g_free(selection);
   gtk_statusbar_pop(GTK_STATUSBAR (Denemo.statusbar), Denemo.status_context_id);
   gtk_statusbar_push(GTK_STATUSBAR (Denemo.statusbar), Denemo.status_context_id,
@@ -1103,7 +1110,7 @@ string_dialog_entry_with_widget (DenemoGUI *gui, gchar *wlabel, gchar *direction
 		gtk_widget_destroy (dialog);
 		return NULL;
 	}
-  return (gchar *)TRUE;
+  return NULL;
 }
 
 static gboolean
@@ -1169,3 +1176,26 @@ gint get_override(GList *g) {
   return ret;
 }
 
+//modfies name to truncate at the extension (a dot at end before any directory separators), returning a pointer to the extension chopped off
+// returns NULL if no extension, with name unchanged
+
+gchar *remove_extension(gchar *name) {
+ gchar *c;
+ if(name)
+   for(c=name+strlen(name);c!=name;c--) {
+     if(*c=='.') {
+       *c = '\0';
+       return c+1;
+     }
+     if(*c==G_DIR_SEPARATOR)
+       break;
+   }
+ return NULL;
+}
+
+//modifies name, removing the extension and returns a newly allocated string
+//with the passed extension
+gchar *substitute_extension(gchar *name, gchar *extension) {
+  (void)remove_extension(name);
+  return g_strdup_printf("%s.%s", name, extension);
+}
